@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,7 +22,7 @@ our $ObjectManagerDisabled = 1;
 
 =head1 NAME
 
-Kernel::GenericInterface::Operation::Ticket::TicketCreate - GenericInterface Ticket TicketCreate Operation backend
+Kernel::GenericInterface::Operation::Ticket::TicketUpdate - GenericInterface Ticket TicketUpdate Operation backend
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,8 @@ sub new {
 
 =item Run()
 
-perform TicketCreate Operation. This will return the created ticket number.
+perform TicketUpdate Operation. This will return the updated TicketID and
+if applicable the created ArticleID.
 
     my $Result = $OperationObject->Run(
         Data => {
@@ -109,6 +110,10 @@ perform TicketCreate Operation. This will return the created ticket number.
                     Hour   => 23,
                     Minute => 05,
                 },
+                # or
+                # PendingTime {
+                #     Diff => 10080, # Pending time in minutes
+                #},
             },
             Article => {                                                          # optional
                 ArticleTypeID                   => 123,                        # optional
@@ -168,10 +173,9 @@ perform TicketCreate Operation. This will return the created ticket number.
         ErrorMessage    => '',                      # in case of error
         Data            => {                        # result data payload after Operation
             TicketID    => 123,                     # Ticket  ID number in OTRS (help desk system)
-            TicketNumber => 2324454323322           # Ticket Number in OTRS (Help desk system)
             ArticleID   => 43,                      # Article ID number in OTRS (help desk system)
             Error => {                              # should not return errors
-                    ErrorCode    => 'Ticket.Create.ErrorCode'
+                    ErrorCode    => 'TicketUpdate.ErrorCode'
                     ErrorMessage => 'Error Description'
             },
         },
@@ -501,9 +505,9 @@ sub Run {
         for my $AttachmentItem (@AttachmentList) {
             if ( !IsHashRefWithData($AttachmentItem) ) {
                 return {
-                    ErrorCode => 'TicketCreate.InvalidParameter',
+                    ErrorCode => 'TicketUpdate.InvalidParameter',
                     ErrorMessage =>
-                        "TicketCreate: Ticket->Attachment parameter is invalid!",
+                        "TicketUpdate: Ticket->Attachment parameter is invalid!",
                 };
             }
 
@@ -1567,7 +1571,7 @@ sub _TicketUpdate {
             ID => $StateID,
         );
 
-        # forse unlock if state type is close
+        # force unlock if state type is close
         if ( $StateData{TypeName} =~ /^close/i ) {
 
             # set lock
