@@ -63,14 +63,15 @@ sub Run {
         next LIBREQUIRED if $LibFound;
 
         return $LayoutObject->ErrorScreen(
-            Message => "Could not find required library $LibRequired",
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Could not find required library %s', $LibRequired ),
         );
     }
 
     # check for valid action backend
     if ( !IsHashRefWithData($ActionsConfig) ) {
         return $LayoutObject->ErrorScreen(
-            Message => $LayoutObject->{LanguageObject}->Translate('Could not get registered configuration for action type %s', $ActionType),
+            Message => $LayoutObject->{LanguageObject}
+                ->Translate( 'Could not get registered configuration for action type %s', $ActionType ),
         );
     }
 
@@ -91,7 +92,8 @@ sub Run {
     # check for valid web service configuration
     if ( !IsHashRefWithData($WebserviceData) ) {
         return $LayoutObject->ErrorScreen(
-            Message => $LayoutObject->{LanguageObject}->Translate('Could not get data for WebserviceID %s', $WebserviceID),
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get data for WebserviceID %s', $WebserviceID ),
         );
     }
 
@@ -101,7 +103,8 @@ sub Run {
     # check for valid action backend
     if ( !$ActionBackend ) {
         return $LayoutObject->ErrorScreen(
-            Message => $LayoutObject->{LanguageObject}->Translate('Could not get backend for %s %s', $ActionType, $Action),
+            Message =>
+                $LayoutObject->{LanguageObject}->Translate( 'Could not get backend for %s %s', $ActionType, $Action ),
         );
     }
 
@@ -188,7 +191,8 @@ sub Run {
         # check for successful web service update
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => $LayoutObject->{LanguageObject}->Translate('Could not update configuration data for WebserviceID %s', $WebserviceID),
+                Message => $LayoutObject->{LanguageObject}
+                    ->Translate( 'Could not update configuration data for WebserviceID %s', $WebserviceID ),
             );
         }
 
