@@ -1,8 +1,5 @@
 # --
-# Kernel/Modules/AdminRoleGroup.pm - to add/update/delete groups <-> users
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: AdminRoleGroup.pm,v 1.32 2011-12-23 13:29:10 mg Exp $
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +11,7 @@ package Kernel::Modules::AdminRoleGroup;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.32 $) [1];
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -24,41 +20,39 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for (qw(ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
-        }
-    }
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $GroupObject  = $Kernel::OM->Get('Kernel::System::Group');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # ------------------------------------------------------------ #
     # user <-> group 1:n
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Role' ) {
 
         # get user data
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
-        my %RoleData = $Self->{GroupObject}->RoleGet( ID => $ID );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my %RoleData = $GroupObject->RoleGet( ID => $ID );
 
         # get group data
-        my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
+        my %GroupData = $GroupObject->GroupList( Valid => 1 );
         my %Types;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my %Data = $Self->{GroupObject}->GroupRoleMemberList(
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my %Data = $GroupObject->PermissionRoleGroupGet(
                 RoleID => $ID,
                 Type   => $Type,
-                Result => 'HASH',
             );
             $Types{$Type} = \%Data;
         }
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
         $Output .= $Self->_Change(
             %Types,
             Data => \%GroupData,
@@ -66,7 +60,7 @@ sub Run {
             Name => $RoleData{Name},
             Type => 'Role',
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 
@@ -76,25 +70,24 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Group' ) {
 
         # get group data
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
-        my %GroupData = $Self->{GroupObject}->GroupGet( ID => $ID );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my %GroupData = $GroupObject->GroupGet( ID => $ID );
 
         # get user list
-        my %RoleData = $Self->{GroupObject}->RoleList( Valid => 1 );
+        my %RoleData = $GroupObject->RoleList( Valid => 1 );
 
         # get permission list users
         my %Types;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my %Data = $Self->{GroupObject}->GroupRoleMemberList(
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my %Data = $GroupObject->PermissionGroupRoleGet(
                 GroupID => $ID,
                 Type    => $Type,
-                Result  => 'HASH',
             );
             $Types{$Type} = \%Data;
         }
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
         $Output .= $Self->_Change(
             %Types,
             Data => \%RoleData,
@@ -102,7 +95,7 @@ sub Run {
             Name => $GroupData{Name},
             Type => 'Group',
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 
@@ -112,38 +105,40 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeGroup' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
 
         # get new groups
         my %Permissions;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my @IDs = $Self->{ParamObject}->GetArray( Param => $Type );
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my @IDs = $ParamObject->GetArray( Param => $Type );
             $Permissions{$Type} = \@IDs;
         }
 
         # get group data
-        my %RoleData = $Self->{GroupObject}->RoleList( Valid => 1 );
+        my %RoleData = $GroupObject->RoleList( Valid => 1 );
         my %NewPermission;
-        for my $RoleID ( keys %RoleData ) {
-            for my $Permission ( keys %Permissions ) {
+        for my $RoleID ( sort keys %RoleData ) {
+            for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
+                ID:
                 for my $ID (@Array) {
+                    next ID if !$ID;
                     if ( $RoleID == $ID ) {
                         $NewPermission{$Permission} = 1;
                     }
                 }
             }
-            $Self->{GroupObject}->GroupRoleMemberAdd(
+            $GroupObject->PermissionGroupRoleAdd(
                 RID        => $RoleID,
                 GID        => $ID,
                 Permission => \%NewPermission,
                 UserID     => $Self->{UserID},
             );
         }
-        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
+        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------ #
@@ -152,58 +147,63 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeRole' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
 
         # get new groups
         my %Permissions;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my @IDs = $Self->{ParamObject}->GetArray( Param => $Type );
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my @IDs = $ParamObject->GetArray( Param => $Type );
             $Permissions{$Type} = \@IDs;
         }
 
         # get group data
-        my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
+        my %GroupData = $GroupObject->GroupList( Valid => 1 );
         my %NewPermission;
-        for my $GroupID ( keys %GroupData ) {
-            for my $Permission ( keys %Permissions ) {
+        for my $GroupID ( sort keys %GroupData ) {
+            for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
+                ID:
                 for my $ID (@Array) {
+                    next ID if !$ID;
                     if ( $GroupID == $ID ) {
                         $NewPermission{$Permission} = 1;
                     }
                 }
             }
-            $Self->{GroupObject}->GroupRoleMemberAdd(
+            $GroupObject->PermissionGroupRoleAdd(
                 RID        => $ID,
                 GID        => $GroupID,
                 Permission => \%NewPermission,
                 UserID     => $Self->{UserID},
             );
         }
-        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
+        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------ #
     # overview
     # ------------------------------------------------------------ #
-    my $Output = $Self->{LayoutObject}->Header();
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $Output = $LayoutObject->Header();
+    $Output .= $LayoutObject->NavigationBar();
     $Output .= $Self->_Overview();
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
     return $Output;
 }
 
 sub _Change {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my %Data   = %{ $Param{Data} };
     my $Type   = $Param{Type} || 'Role';
     my $NeType = $Type eq 'Group' ? 'Role' : 'Group';
 
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'Change',
         Data => {
             %Param,
@@ -211,15 +211,26 @@ sub _Change {
             NeType     => $NeType,
         },
     );
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionOverview' );
 
-    $Self->{LayoutObject}->Block( Name => "ChangeHeader$NeType" );
+    $LayoutObject->Block( Name => "ChangeHeader$NeType" );
 
-    for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-        next if !$Type;
+    # check if there are groups/roles
+    if ( !%Data ) {
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsgList',
+            Data => {
+                ColSpan => 8,
+            },
+        );
+    }
+
+    TYPE:
+    for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+        next TYPE if !$Type;
         my $Mark = $Type eq 'rw' ? "Highlight" : '';
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ChangeHeader',
             Data => {
                 %Param,
@@ -232,7 +243,7 @@ sub _Change {
     for my $ID ( sort { uc( $Data{$a} ) cmp uc( $Data{$b} ) } keys %Data ) {
 
         # set output class
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ChangeRow',
             Data => {
                 %Param,
@@ -241,12 +252,13 @@ sub _Change {
                 NeType => $NeType,
             },
         );
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            next if !$Type;
+        TYPE:
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            next TYPE if !$Type;
             my $Mark     = $Type eq 'rw'        ? "Highlight"          : '';
             my $Selected = $Param{$Type}->{$ID} ? ' checked="checked"' : '';
 
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ChangeRowItem',
                 Data => {
                     %Param,
@@ -260,7 +272,7 @@ sub _Change {
         }
     }
 
-    return $Self->{LayoutObject}->Output(
+    return $LayoutObject->Output(
         TemplateFile => 'AdminRoleGroup',
         Data         => \%Param,
     );
@@ -269,19 +281,22 @@ sub _Change {
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    $Self->{LayoutObject}->Block(
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $GroupObject  = $Kernel::OM->Get('Kernel::System::Group');
+
+    $LayoutObject->Block(
         Name => 'Overview',
         Data => {},
     );
 
     # get user list
-    my %RoleData = $Self->{GroupObject}->RoleList( Valid => 1 );
+    my %RoleData = $GroupObject->RoleList( Valid => 1 );
 
     if (%RoleData) {
         for my $RoleID ( sort { uc( $RoleData{$a} ) cmp uc( $RoleData{$b} ) } keys %RoleData ) {
 
             # set output class
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'List1n',
                 Data => {
                     Name      => $RoleData{$RoleID},
@@ -292,29 +307,38 @@ sub _Overview {
         }
     }
     else {
-        $Self->{LayoutObject}->Block(
-            Name => 'NoDataFoundMsg',
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsgRole',
             Data => {},
         );
     }
 
     # get group data
-    my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
-    for my $GroupID ( sort { uc( $GroupData{$a} ) cmp uc( $GroupData{$b} ) } keys %GroupData ) {
+    my %GroupData = $GroupObject->GroupList( Valid => 1 );
 
-        # set output class
-        $Self->{LayoutObject}->Block(
-            Name => 'Listn1',
-            Data => {
-                Name      => $GroupData{$GroupID},
-                Subaction => 'Group',
-                ID        => $GroupID,
-            },
+    if (%GroupData) {
+        for my $GroupID ( sort { uc( $GroupData{$a} ) cmp uc( $GroupData{$b} ) } keys %GroupData ) {
+
+            # set output class
+            $LayoutObject->Block(
+                Name => 'Listn1',
+                Data => {
+                    Name      => $GroupData{$GroupID},
+                    Subaction => 'Group',
+                    ID        => $GroupID,
+                },
+            );
+        }
+    }
+    else {
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsgGroup',
+            Data => {},
         );
     }
 
     # return output
-    return $Self->{LayoutObject}->Output(
+    return $LayoutObject->Output(
         TemplateFile => 'AdminRoleGroup',
         Data         => \%Param,
     );
