@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminSession;
@@ -105,17 +105,14 @@ sub Run {
                 }
                 if ( $Key eq 'UserSessionStart' ) {
 
-                    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-                    my $Age            = int(
-                        ( $DateTimeObject->ToEpoch() - $Data{UserSessionStart} )
+                    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
+                    my $Age        = int(
+                        ( $TimeObject->SystemTime() - $Data{UserSessionStart} )
                         / 3600
                     );
-                    my $TimeStamp = $Kernel::OM->Create(
-                        'Kernel::System::DateTime',
-                        ObjectParams => {
-                            Epoch => $Data{UserSessionStart},
-                        }
-                    )->ToString();
+                    my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
+                        SystemTime => $Data{UserSessionStart},
+                    );
                     $Data{$Key} = "$TimeStamp / $Age h ";
                 }
                 if ( $Data{$Key} eq ';' ) {
@@ -142,10 +139,6 @@ sub Run {
 
         $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminSession',
-            Data         => {
-                Action => $Self->{Subaction},
-                %Data,
-            },
         );
 
         $Output .= $LayoutObject->Footer();
@@ -171,22 +164,16 @@ sub Run {
             Name => 'Overview',
         );
 
-        $LayoutObject->Block(
-            Name => 'Filter'
-        );
-
         for my $SessionID (@List) {
             my $List = '';
             my %Data = $SessionObject->GetSessionIDData( SessionID => $SessionID );
-            if ( $Data{UserType} && $Data{UserLogin} ) {
-                $MetaData{"$Data{UserType}Session"}++;
-                if ( !$MetaData{"$Data{UserLogin}"} ) {
-                    $MetaData{"$Data{UserType}SessionUniq"}++;
-                    $MetaData{"$Data{UserLogin}"} = 1;
-                }
+            $MetaData{"$Data{UserType}Session"}++;
+            if ( !$MetaData{"$Data{UserLogin}"} ) {
+                $MetaData{"$Data{UserType}SessionUniq"}++;
+                $MetaData{"$Data{UserLogin}"} = 1;
             }
 
-            $Data{UserType} = 'Agent' if ( !$Data{UserType} || $Data{UserType} ne 'Customer' );
+            $Data{UserType} = 'Agent' if ( $Data{UserType} ne 'Customer' );
 
             # create blocks
             $LayoutObject->Block(
@@ -195,7 +182,6 @@ sub Run {
                     SessionID     => $SessionID,
                     UserFirstname => $Data{UserFirstname},
                     UserLastname  => $Data{UserLastname},
-                    UserFullname  => $Data{UserFullname},
                     UserType      => $Data{UserType},
                 },
             );
@@ -210,7 +196,7 @@ sub Run {
             Data => {
                 Counter => $Counter,
                 %MetaData
-            }
+                }
         );
 
         # generate output
@@ -221,7 +207,7 @@ sub Run {
             Data         => {
                 Counter => $Counter,
                 %MetaData
-            }
+                }
         );
         $Output .= $LayoutObject->Footer();
         return $Output;
