@@ -11,6 +11,8 @@ package Kernel::Modules::AdminUserGroup;
 use strict;
 use warnings;
 
+our $ObjectManagerDisabled = 1;
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,41 +20,47 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for (qw(ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject)) {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
-        }
-    }
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $GroupObject  = $Kernel::OM->Get('Kernel::System::Group');
+    my $UserObject   = $Kernel::OM->Get('Kernel::System::User');
+
     # ------------------------------------------------------------ #
     # user <-> group 1:n
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'User' ) {
 
         # get user data
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
-        my %UserData = $Self->{UserObject}->GetUserData( UserID => $ID );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
+
+        my %UserData = $UserObject->GetUserData(
+            UserID => $ID,
+        );
 
         # get group data
-        my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
+        my %GroupData = $GroupObject->GroupList(
+            Valid => 1,
+        );
         my %Types;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my %Data = $Self->{GroupObject}->GroupGroupMemberList(
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+
+            my %Data = $GroupObject->PermissionUserGroupGet(
                 UserID => $ID,
                 Type   => $Type,
-                Result => 'HASH',
             );
             $Types{$Type} = \%Data;
         }
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
         $Output .= $Self->_Change(
             %Types,
             Data => \%GroupData,
@@ -60,7 +68,7 @@ sub Run {
             Name => "$UserData{UserFirstname} $UserData{UserLastname} ($UserData{UserLogin})",
             Type => 'User',
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 
@@ -70,32 +78,40 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Group' ) {
 
         # get group data
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
-        my %GroupData = $Self->{GroupObject}->GroupGet( ID => $ID );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
+
+        my %GroupData = $GroupObject->GroupGet(
+            ID => $ID,
+        );
 
         # get user list
-        my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
+        my %UserData = $UserObject->UserList(
+            Valid => 1,
+        );
 
         # get user name
+        USERID:
         for my $UserID ( sort keys %UserData ) {
-            my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
-            next if !$Name;
+            my $Name = $UserObject->UserName(
+                UserID => $UserID,
+            );
+            next USERID if !$Name;
             $UserData{$UserID} .= " ($Name)";
         }
 
         # get permission list users
         my %Types;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my %Data = $Self->{GroupObject}->GroupGroupMemberList(
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+
+            my %Data = $GroupObject->PermissionGroupUserGet(
                 GroupID => $ID,
                 Type    => $Type,
-                Result  => 'HASH',
             );
             $Types{$Type} = \%Data;
         }
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
         $Output .= $Self->_Change(
             %Types,
             Data => \%UserData,
@@ -103,7 +119,7 @@ sub Run {
             Name => $GroupData{Name},
             Type => 'Group',
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 
@@ -113,38 +129,44 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeGroup' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
 
         # get new groups
         my %Permissions;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my @IDs = $Self->{ParamObject}->GetArray( Param => $Type );
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my @IDs = $ParamObject->GetArray( Param => $Type );
             $Permissions{$Type} = \@IDs;
         }
 
         # get group data
-        my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
+        my %UserData = $UserObject->UserList(
+            Valid => 1,
+        );
         my %NewPermission;
         for my $UserID ( sort keys %UserData ) {
             for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
+                ID:
                 for my $ID (@Array) {
+                    next ID if !$ID;
                     if ( $UserID == $ID ) {
                         $NewPermission{$Permission} = 1;
                     }
                 }
             }
-            $Self->{GroupObject}->GroupMemberAdd(
+            $GroupObject->PermissionGroupUserAdd(
                 UID        => $UserID,
                 GID        => $ID,
                 Permission => \%NewPermission,
                 UserID     => $Self->{UserID},
             );
         }
-        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
+        return $LayoutObject->Redirect(
+            OP => "Action=$Self->{Action}",
+        );
     }
 
     # ------------------------------------------------------------ #
@@ -153,47 +175,53 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeUser' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
+        my $ID = $ParamObject->GetParam( Param => 'ID' );
 
         # get new groups
         my %Permissions;
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            my @IDs = $Self->{ParamObject}->GetArray( Param => $Type );
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            my @IDs = $ParamObject->GetArray( Param => $Type );
             $Permissions{$Type} = \@IDs;
         }
 
         # get group data
-        my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
+        my %GroupData = $GroupObject->GroupList(
+            Valid => 1,
+        );
         my %NewPermission;
         for my $GroupID ( sort keys %GroupData ) {
             for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
+                ID:
                 for my $ID (@Array) {
+                    next ID if !$ID;
                     if ( $GroupID eq $ID ) {
                         $NewPermission{$Permission} = 1;
                     }
                 }
             }
-            $Self->{GroupObject}->GroupMemberAdd(
+            $GroupObject->PermissionGroupUserAdd(
                 UID        => $ID,
                 GID        => $GroupID,
                 Permission => \%NewPermission,
                 UserID     => $Self->{UserID},
             );
         }
-        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
+        return $LayoutObject->Redirect(
+            OP => "Action=$Self->{Action}",
+        );
     }
 
     # ------------------------------------------------------------ #
     # overview
     # ------------------------------------------------------------ #
-    my $Output = $Self->{LayoutObject}->Header();
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $Output = $LayoutObject->Header();
+    $Output .= $LayoutObject->NavigationBar();
     $Output .= $Self->_Overview();
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
     return $Output;
 }
 
@@ -209,13 +237,19 @@ sub _Change {
         User  => 'Agent',
     );
 
-    $Self->{LayoutObject}->Block( Name => 'Overview' );
-    $Self->{LayoutObject}->Block( Name => 'ActionList' );
-    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
-    $Self->{LayoutObject}->Block(
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    $LayoutObject->Block(
+        Name => 'ActionList',
+    );
+    $LayoutObject->Block(
+        Name => 'ActionOverview',
+    );
+    $LayoutObject->Block(
         Name => 'ChangeReference',
     );
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'Change',
         Data => {
             %Param,
@@ -226,12 +260,30 @@ sub _Change {
         },
     );
 
-    $Self->{LayoutObject}->Block( Name => "ChangeHeader$VisibleType{$NeType}" );
+    $LayoutObject->Block(
+        Name => "ChangeHeader$VisibleType{$NeType}",
+    );
 
-    for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-        next if !$Type;
+    # check if there are groups
+    if ( $NeType eq 'Group' ) {
+        if ( !%Data ) {
+            $LayoutObject->Block(
+                Name => 'NoDataFoundMsgList',
+                Data => {
+                    ColSpan => 8,
+                },
+            );
+        }
+    }
+
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    TYPE:
+    for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+        next TYPE if !$Type;
         my $Mark = $Type eq 'rw' ? "Highlight" : '';
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ChangeHeader',
             Data => {
                 %Param,
@@ -244,7 +296,7 @@ sub _Change {
     for my $ID ( sort { uc( $Data{$a} ) cmp uc( $Data{$b} ) } keys %Data ) {
 
         # set output class
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'ChangeRow',
             Data => {
                 %Param,
@@ -253,12 +305,13 @@ sub _Change {
                 NeType => $NeType,
             },
         );
-        for my $Type ( @{ $Self->{ConfigObject}->Get('System::Permission') } ) {
-            next if !$Type;
+        TYPE:
+        for my $Type ( @{ $ConfigObject->Get('System::Permission') } ) {
+            next TYPE if !$Type;
             my $Mark     = $Type eq 'rw'        ? "Highlight"          : '';
             my $Selected = $Param{$Type}->{$ID} ? ' checked="checked"' : '';
 
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'ChangeRowItem',
                 Data => {
                     %Param,
@@ -272,7 +325,7 @@ sub _Change {
         }
     }
 
-    return $Self->{LayoutObject}->Output(
+    return $LayoutObject->Output(
         TemplateFile => 'AdminUserGroup',
         Data         => \%Param,
     );
@@ -281,28 +334,49 @@ sub _Change {
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    $Self->{LayoutObject}->Block( Name => 'Overview' );
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    # no "actions list" block because no actions now
-    #    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $LayoutObject->Block(
+        Name => 'Overview',
+    );
 
-    $Self->{LayoutObject}->Block( Name => 'UserFilter' );
-    $Self->{LayoutObject}->Block( Name => 'GroupFilter' );
-    $Self->{LayoutObject}->Block( Name => 'OverviewResult' );
+    $LayoutObject->Block(
+        Name => 'ActionList',
+    );
+    $LayoutObject->Block(
+        Name => 'NewActions',
+    );
+
+    $LayoutObject->Block(
+        Name => 'UserFilter',
+    );
+    $LayoutObject->Block(
+        Name => 'GroupFilter',
+    );
+    $LayoutObject->Block(
+        Name => 'OverviewResult',
+    );
+
+    # get use object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
 
     # get user list
-    my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
+    my %UserData = $UserObject->UserList(
+        Valid => 1,
+    );
 
     # get user name
+    USERID:
     for my $UserID ( sort keys %UserData ) {
-        my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
-        next if !$Name;
+        my $Name = $UserObject->UserName( UserID => $UserID );
+        next USERID if !$Name;
         $UserData{$UserID} .= " ($Name)";
     }
     for my $UserID ( sort { uc( $UserData{$a} ) cmp uc( $UserData{$b} ) } keys %UserData ) {
 
         # set output class
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'List1n',
             Data => {
                 Name      => $UserData{$UserID},
@@ -313,22 +387,33 @@ sub _Overview {
     }
 
     # get group data
-    my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
-    for my $GroupID ( sort { uc( $GroupData{$a} ) cmp uc( $GroupData{$b} ) } keys %GroupData ) {
+    my %GroupData = $Kernel::OM->Get('Kernel::System::Group')->GroupList(
+        Valid => 1,
+    );
 
-        # set output class
-        $Self->{LayoutObject}->Block(
-            Name => 'Listn1',
-            Data => {
-                Name      => $GroupData{$GroupID},
-                Subaction => 'Group',
-                ID        => $GroupID,
-            },
+    if (%GroupData) {
+        for my $GroupID ( sort { uc( $GroupData{$a} ) cmp uc( $GroupData{$b} ) } keys %GroupData ) {
+
+            # set output class
+            $LayoutObject->Block(
+                Name => 'Listn1',
+                Data => {
+                    Name      => $GroupData{$GroupID},
+                    Subaction => 'Group',
+                    ID        => $GroupID,
+                },
+            );
+        }
+    }
+    else {
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsg',
+            Data => {},
         );
     }
 
     # return output
-    return $Self->{LayoutObject}->Output(
+    return $LayoutObject->Output(
         TemplateFile => 'AdminUserGroup',
         Data         => \%Param,
     );
