@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Layout::LinkObject;
@@ -21,13 +21,15 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::Output::HTML::Layout::LinkObject - all LinkObject-related HTML functions
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All LinkObject-related HTML functions
 
 =head1 PUBLIC INTERFACE
 
-=head2 LinkObjectTableCreate()
+=over 4
+
+=item LinkObjectTableCreate()
 
 create a output table
 
@@ -55,25 +57,23 @@ sub LinkObjectTableCreate {
     if ( $Param{ViewMode} =~ m{ \A Simple }xms ) {
 
         return $Self->LinkObjectTableCreateSimple(
-            LinkListWithData               => $Param{LinkListWithData},
-            ViewMode                       => $Param{ViewMode},
-            AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
+            LinkListWithData => $Param{LinkListWithData},
+            ViewMode         => $Param{ViewMode},
         );
     }
     else {
 
         return $Self->LinkObjectTableCreateComplex(
-            LinkListWithData               => $Param{LinkListWithData},
-            ViewMode                       => $Param{ViewMode},
-            AJAX                           => $Param{AJAX},
-            SourceObject                   => $Param{Object},
-            ObjectID                       => $Param{Key},
-            AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
+            LinkListWithData => $Param{LinkListWithData},
+            ViewMode         => $Param{ViewMode},
+            AJAX             => $Param{AJAX},
+            SourceObject     => $Param{Object},
+            ObjectID         => $Param{Key},
         );
     }
 }
 
-=head2 LinkObjectTableCreateComplex()
+=item LinkObjectTableCreateComplex()
 
 create a complex output table
 
@@ -90,10 +90,6 @@ sub LinkObjectTableCreateComplex {
     # get log object
     my $LogObject = $Kernel::OM->Get('Kernel::System::Log');
 
-    # create new instance of the layout object
-    my $LayoutObject  = Kernel::Output::HTML::Layout->new( %{$Self} );
-    my $LayoutObject2 = Kernel::Output::HTML::Layout->new( %{$Self} );
-
     # check needed stuff
     for my $Argument (qw(LinkListWithData ViewMode)) {
         if ( !$Param{$Argument} ) {
@@ -185,9 +181,6 @@ sub LinkObjectTableCreateComplex {
         }
     }
 
-    # get config option to show the link delete button
-    my $ShowDeleteButton = $Kernel::OM->Get('Kernel::Config')->Get('LinkObject::ShowDeleteButton');
-
     # add "linked as" column to the table
     for my $Block (@OutputData) {
 
@@ -199,70 +192,11 @@ sub LinkObjectTableCreateComplex {
         # add new column to the headline
         push @{ $Block->{Headline} }, $Column;
 
-        # permission check
-        my $SourcePermission;
-        if ( $Param{SourceObject} && $Param{ObjectID} && $ShowDeleteButton ) {
-
-            # get source permission
-            $SourcePermission = $Kernel::OM->Get('Kernel::System::LinkObject')->ObjectPermission(
-                Object => $Param{SourceObject},
-                Key    => $Param{ObjectID},
-                UserID => $Self->{UserID},
-            );
-
-            # we show the column headline if we got source permission
-            if ($SourcePermission) {
-                $Column = {
-                    Content  => $Kernel::OM->Get('Kernel::Language')->Translate('Delete'),
-                    CssClass => 'Center Last',
-                };
-
-                # add new column to the headline
-                push @{ $Block->{Headline} }, $Column;
-            }
-
-        }
         for my $Item ( @{ $Block->{ItemList} } ) {
 
-            my %LinkDeleteData;
-            my $TargetPermission;
-
-            # Search for key.
+            # search for key
             my ($ItemWithKey) = grep { $_->{Key} } @{$Item};
 
-            if ( $Param{SourceObject} && $Param{ObjectID} && $ItemWithKey->{Key} && $ShowDeleteButton ) {
-
-                for my $LinkType ( sort keys %{ $LinkList{ $Block->{Object} }->{ $ItemWithKey->{Key} } } ) {
-
-                    # get target permission
-                    $TargetPermission = $Kernel::OM->Get('Kernel::System::LinkObject')->ObjectPermission(
-                        Object => $Block->{Object},
-                        Key    => $ItemWithKey->{Key},
-                        UserID => $Self->{UserID},
-                    );
-
-                    # build the delete link only if we also got target permission
-                    if ($TargetPermission) {
-
-                        my %InstantLinkDeleteData;
-
-                        # depending on the link type direction source and target must be switched
-                        if ( $LinkList{ $Block->{Object} }->{ $ItemWithKey->{Key} }->{$LinkType} eq 'Source' ) {
-                            $LinkDeleteData{SourceObject} = $Block->{Object};
-                            $LinkDeleteData{SourceKey}    = $ItemWithKey->{Key};
-                            $LinkDeleteData{TargetIdentifier}
-                                = $Param{SourceObject} . '::' . $Param{ObjectID} . '::' . $LinkType;
-                        }
-                        else {
-                            $LinkDeleteData{SourceObject} = $Param{SourceObject};
-                            $LinkDeleteData{SourceKey}    = $Param{ObjectID};
-                            $LinkDeleteData{TargetIdentifier}
-                                = $Block->{Object} . '::' . $ItemWithKey->{Key} . '::' . $LinkType;
-                        }
-                    }
-                }
-            }
-
             # define check-box cell
             my $CheckboxCell = {
                 Type         => 'LinkTypeList',
@@ -273,30 +207,6 @@ sub LinkObjectTableCreateComplex {
 
             # add check-box cell to item
             push @{$Item}, $CheckboxCell;
-
-            # check if delete icon should be shown
-            if ( $Param{SourceObject} && $Param{ObjectID} && $SourcePermission && $ShowDeleteButton ) {
-
-                if ($TargetPermission) {
-
-                    # build delete link
-                    push @{$Item}, {
-                        Type      => 'DeleteLinkIcon',
-                        CssClass  => 'Center Last',
-                        Translate => 1,
-                        %LinkDeleteData,
-                    };
-                }
-                else {
-                    # build no delete link, instead use empty values
-                    # to keep table formatting correct
-                    push @{$Item}, {
-                        Type     => 'Plain',
-                        CssClass => 'Center Last',
-                        Content  => '',
-                    };
-                }
-            }
         }
     }
 
@@ -307,7 +217,9 @@ sub LinkObjectTableCreateComplex {
         for my $Block (@OutputData) {
 
             # define the headline column
-            my $Column;
+            my $Column = {
+                Content => 'Select',
+            };
 
             # add new column to the headline
             unshift @{ $Block->{Headline} }, $Column;
@@ -363,9 +275,9 @@ sub LinkObjectTableCreateComplex {
         }
     }
 
-    # # create new instance of the layout object
-    # my $LayoutObject  = Kernel::Output::HTML::Layout->new( %{$Self} );
-    # my $LayoutObject2 = Kernel::Output::HTML::Layout->new( %{$Self} );
+    # create new instance of the layout object
+    my $LayoutObject  = Kernel::Output::HTML::Layout->new( %{$Self} );
+    my $LayoutObject2 = Kernel::Output::HTML::Layout->new( %{$Self} );
 
     # output the table complex block
     $LayoutObject->Block(
@@ -377,7 +289,7 @@ sub LinkObjectTableCreateComplex {
 
     my $BlockCounter = 0;
 
-    my $Config             = $Kernel::OM->Get('Kernel::Config')->Get("LinkObject::ComplexTable") || {};
+    my $Config = $Kernel::OM->Get('Kernel::Config')->Get("LinkObject::ComplexTable") || {};
     my $SettingsVisibility = $Kernel::OM->Get('Kernel::Config')->Get("LinkObject::ComplexTable::SettingsVisibility")
         || {};
 
@@ -400,7 +312,6 @@ sub LinkObjectTableCreateComplex {
     my $OriginalAction = $Kernel::OM->Get('Kernel::System::Web::Request')->GetParam( Param => 'OriginalAction' )
         || $Self->{Action};
 
-    my @LinkObjectTables;
     BLOCK:
     for my $Block (@OutputData) {
 
@@ -413,7 +324,7 @@ sub LinkObjectTableCreateComplex {
             Name => 'TableComplexBlock',
             Data => {
                 BlockDescription => $BlockDescription,
-                Blockname        => $Block->{Blockname} . ' (' . scalar @{ $Block->{ItemList} } . ')',
+                Blockname        => $Block->{Blockname} || '',
                 Name             => $Block->{Blockname},
                 NameForm         => $Block->{Blockname},
                 AJAX             => $Param{AJAX},
@@ -422,9 +333,7 @@ sub LinkObjectTableCreateComplex {
 
         # check if registered in SysConfig
         if (
-            # AgentLinkObject not allowed because it would result in nested forms
-            $OriginalAction ne 'AgentLinkObject'
-            && IsHashRefWithData($Config)
+            IsHashRefWithData($Config)
             && $Config->{ $Block->{Blockname} }
             && grep { $OriginalAction eq $_ } @SettingsVisible
             )
@@ -446,37 +355,17 @@ sub LinkObjectTableCreateComplex {
                 PrefKey => "LinkObject::ComplexTable-" . $Block->{Blockname},
             );
 
-            # Add translations for the allocation lists for regular columns.
-            for my $Column ( @{ $Block->{AllColumns} } ) {
-                $LayoutObject->AddJSData(
-                    Key   => 'Column' . $Column->{ColumnName},
-                    Value => $LayoutObject->{LanguageObject}->Translate( $Column->{ColumnTranslate} ),
-                );
-            }
-
-            # Prepare LinkObjectTables for JS config.
-            push @LinkObjectTables, $Block->{Blockname};
-
-            $LayoutObject->Block(
-                Name => 'ContentLargePreferencesForm',
-                Data => {
-                    Name     => $Block->{Blockname},
-                    NameForm => $Block->{Blockname},
-                },
-            );
-
             $LayoutObject->Block(
                 Name => $Preferences{Name} . 'PreferencesItem' . $Preferences{Block},
                 Data => {
                     %Preferences,
-                    NameForm                       => $Block->{Blockname},
-                    NamePref                       => $Preferences{Name},
-                    Name                           => $Block->{Blockname},
-                    SourceObject                   => $Param{SourceObject},
-                    DestinationObject              => $Block->{Blockname},
-                    OriginalAction                 => $OriginalAction,
-                    SourceObjectData               => $SourceObjectData,
-                    AdditionalLinkListWithDataJSON => $Param{AdditionalLinkListWithDataJSON},
+                    NameForm          => $Block->{Blockname},
+                    NamePref          => $Preferences{Name},
+                    Name              => $Block->{Blockname},
+                    SourceObject      => $Param{SourceObject},
+                    DestinationObject => $Block->{Blockname},
+                    OriginalAction    => $OriginalAction,
+                    SourceObjectData  => $SourceObjectData,
                 },
             );
         }
@@ -575,19 +464,13 @@ sub LinkObjectTableCreateComplex {
         $BlockCounter++;
     }
 
-    # Send LinkObjectTables to JS.
-    $LayoutObject->AddJSData(
-        Key   => 'LinkObjectTables',
-        Value => \@LinkObjectTables,
-    );
-
     return $LayoutObject->Output(
-        TemplateFile => 'LinkObject',
-        AJAX         => $Param{AJAX},
+        TemplateFile   => 'LinkObject',
+        KeepScriptTags => $Param{AJAX},
     );
 }
 
-=head2 LinkObjectTableCreateSimple()
+=item LinkObjectTableCreateSimple()
 
 create a simple output table
 
@@ -605,7 +488,7 @@ sub LinkObjectTableCreateSimple {
     if ( !$Param{LinkListWithData} || ref $Param{LinkListWithData} ne 'HASH' ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need LinkListWithData!',
+            Message  => 'Need LinkListWithData!'
         );
         return;
     }
@@ -659,7 +542,7 @@ sub LinkObjectTableCreateSimple {
         }
 
         # investigate link type name
-        my @LinkData     = split q{::}, $LinkTypeLinkDirection;
+        my @LinkData = split q{::}, $LinkTypeLinkDirection;
         my $LinkTypeName = $TypeList{ $LinkData[0] }->{ $LinkData[1] . 'Name' };
 
         # output the type block
@@ -709,9 +592,9 @@ sub LinkObjectTableCreateSimple {
     );
 }
 
-=head2 LinkObjectSelectableObjectList()
+=item LinkObjectSelectableObjectList()
 
-return a selection list of link-able objects
+return a selection list of linkable objects
 
     my $String = $LayoutObject->LinkObjectSelectableObjectList(
         Object   => 'Ticket',
@@ -814,7 +697,7 @@ sub LinkObjectSelectableObjectList {
     return $TargetObjectStrg;
 }
 
-=head2 LinkObjectSearchOptionList()
+=item LinkObjectSearchOptionList()
 
 return a list of search options
 
@@ -852,7 +735,7 @@ sub LinkObjectSearchOptionList {
     return @SearchOptionList;
 }
 
-=head2 ComplexTablePreferencesGet()
+=item ComplexTablePreferencesGet()
 
 get items needed for AllocationList initialization.
 
@@ -974,7 +857,7 @@ sub ComplexTablePreferencesGet {
     return %Params;
 }
 
-=head2 ComplexTablePreferencesSet()
+=item ComplexTablePreferencesSet()
 
 set user preferences.
 
@@ -1072,7 +955,7 @@ sub ComplexTablePreferencesSet {
 
 =begin Internal:
 
-=head2 _LinkObjectContentStringCreate()
+=item _LinkObjectContentStringCreate()
 
 return a output string
 
@@ -1164,7 +1047,7 @@ sub _LinkObjectContentStringCreate {
 
         # transform ascii to html
         $Content->{Content} = $Param{LayoutObject}->Ascii2Html(
-            Text           => $String || '-',
+            Text => $String || '-',
             HTMLResultMode => 1,
             LinkFeature    => 0,
         );
@@ -1241,7 +1124,7 @@ sub _LinkObjectContentStringCreate {
     );
 }
 
-=head2 _LoadLinkObjectLayoutBackend()
+=item _LoadLinkObjectLayoutBackend()
 
 load a linkobject layout backend module
 
@@ -1307,12 +1190,14 @@ sub _LoadLinkObjectLayoutBackend {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
