@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Layout::Template;
@@ -23,11 +23,13 @@ our $ObjectManagerDisabled = 1;
 
 =head1 NAME
 
-Kernel::Output::HTML::Layout::Template - template rendering engine based on Template::Toolkit
+Kernel::Output::HTML::LayoutTemplate - template rendering engine based on Template::Toolkit
 
 =head1 PUBLIC INTERFACE
 
-=head2 Output()
+=over 4
+
+=item Output()
 
 generates HTML output based on a template file.
 
@@ -47,18 +49,15 @@ Using a template string:
 
 Additional parameters:
 
-    AJAX - AJAX-specific adjustements: this causes [% WRAPPER JSOnDocumentComplete %] blocks NOT
+    KeepScriptTags - this causes [% WRAPPER JSOnDocumentComplete %] blocks NOT
         to be replaced. This is important to be able to generate snippets which can be cached.
-        Also, JS data added with AddJSData() calls is appended to the output here.
 
     my $HTML = $LayoutObject->Output(
         TemplateFile   => 'AdminLog.tt',
         Data           => \%Param,
-        AJAX           => 1,
+        KeepScriptTags => 1,
     );
 
-    KeepScriptTags - DEPRECATED, please use the parameter "AJAX" instead
-
 =cut
 
 sub Output {
@@ -75,11 +74,6 @@ sub Output {
         $Self->FatalError();
     }
 
-    # asure compatibility with old KeepScriptTags parameter
-    if ( $Param{KeepScriptTags} && !$Param{AJAX} ) {
-        $Param{AJAX} = $Param{KeepScriptTags};
-    }
-
     # fill init Env
     if ( !$Self->{EnvRef} ) {
         %{ $Self->{EnvRef} } = %ENV;
@@ -191,10 +185,10 @@ sub Output {
     my $Success = $Self->{TemplateObject}->process(
         $Param{TemplateFileTT} // \$TemplateString,
         {
-            Data   => $Param{Data} // {},
+            Data => $Param{Data} // {},
             global => {
-                BlockData      => $Self->{BlockData} // [],
-                KeepScriptTags => $Param{AJAX}       // 0,
+                BlockData      => $Self->{BlockData}     // [],
+                KeepScriptTags => $Param{KeepScriptTags} // 0,
             },
         },
         \$Output,
@@ -220,7 +214,7 @@ sub Output {
             my $Target  = $2;
             my $End     = $3;
             my $RealEnd = $4;
-            if ( lc($Target) =~ /^(http:|https:|#|ftp:)/ ||
+            if ( lc $Target =~ /^(http:|https:|#|ftp:)/ ||
                 $Target !~ /\.(pl|php|cgi|fcg|fcgi|fpl)(\?|$)/ ||
                 $Target =~ /(\?|&|;)\Q$Self->{SessionName}\E=/) {
                 $AHref.$Target.$End.$RealEnd;
@@ -238,7 +232,7 @@ sub Output {
             my $AHref = $1;
             my $Target = $2;
             my $End = $3;
-            if (lc($Target) =~ m{^http s? :}smx || !$Self->{SessionID} ||
+            if (lc $Target =~ m{^http s? :}smx || !$Self->{SessionID} ||
                 $Target !~ /\.(pl|php|cgi|fcg|fcgi|fpl)(\?|$)/ ||
                 $Target =~ /\Q$Self->{SessionName}\E=/) {
                 $AHref.$Target.$End;
@@ -290,26 +284,10 @@ sub Output {
         }
     }
 
-    #
-    # AddJSData() handling
-    #
-    if ( $Param{AJAX} ) {
-        my %Data = %{ $Self->{_JSData} // {} };
-        if (%Data) {
-            my $JSONString = $Kernel::OM->Get('Kernel::System::JSON')->Encode(
-                Data     => \%Data,
-                SortKeys => 1,
-            );
-            $Output
-                .= "\n<script type=\"text/javascript\">//<![CDATA[\n\"use strict\";\nCore.Config.AddConfig($JSONString);\n//]]></script>";
-        }
-        delete $Self->{_JSData};
-    }
-
     return $Output;
 }
 
-=head2 AddJSOnDocumentComplete()
+=item AddJSOnDocumentComplete()
 
 dynamically add JavaScript code that should be executed in Core.App.Ready().
 Call this for any dynamically generated code that is not in a template.
@@ -326,40 +304,18 @@ sub AddJSOnDocumentComplete {
     $Self->{_JSOnDocumentComplete} //= [];
     push @{ $Self->{_JSOnDocumentComplete} }, $Param{Code};
 
-    return;
-}
-
-=head2 AddJSData()
-
-dynamically add JavaScript data that should be handed over to
-JavaScript via Core.Config.
-
-    $LayoutObject->AddJSData(
-        Key   => 'Key1',  # the key to store this data
-        Value => { ... }  # simple or complex data
-    );
-
-=cut
-
-sub AddJSData {
-    my ( $Self, %Param ) = @_;
-
-    return if !$Param{Key};
-
-    $Self->{_JSData} //= {};
-    $Self->{_JSData}->{ $Param{Key} } = $Param{Value};
-
-    return;
 }
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
