@@ -1,15 +1,13 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::Notification::CustomerOTRSBusiness;
 
-use parent 'Kernel::Output::HTML::Base';
-
 use strict;
 use warnings;
 use utf8;
@@ -19,6 +17,16 @@ our @ObjectDependencies = (
     'Kernel::Output::HTML::Layout',
 );
 
+sub new {
+    my ( $Type, %Param ) = @_;
+
+    # allocate new hash for object
+    my $Self = {};
+    bless( $Self, $Type );
+
+    return $Self;
+}
+
 sub Run {
     my ( $Self, %Param ) = @_;
 
@@ -38,16 +46,7 @@ sub Run {
 
     if ( $EntitlementStatus eq 'warning-error' || $EntitlementStatus eq 'forbidden' ) {
 
-        my $OTRSBusinessLabel;
-        if ( $OTRSBusinessObject->OTRSSTORMIsInstalled() ) {
-            $OTRSBusinessLabel = '<b>STORM powered by OTRS</b>™';
-        }
-        elsif ( $OTRSBusinessObject->OTRSCONTROLIsInstalled() ) {
-            $OTRSBusinessLabel = '<b>CONTROL powered by OTRS</b>™';
-        }
-        else {
-            $OTRSBusinessLabel = '<b>OTRS Business Solution</b>™';
-        }
+        my $OTRSBusinessLabel = '<b>OTRS Business Solution</b>™';
 
         # get layout object
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
