@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Output::HTML::TicketOverview::Preview;
@@ -16,17 +16,14 @@ use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
-    'Kernel::System::CommunicationChannel',
     'Kernel::System::CustomerUser',
     'Kernel::System::SystemAddress',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
-    'Kernel::System::Group',
     'Kernel::System::Log',
     'Kernel::Output::HTML::Layout',
     'Kernel::System::User',
     'Kernel::System::Ticket',
-    'Kernel::System::Ticket::Article',
     'Kernel::System::Main',
     'Kernel::System::Queue',
 );
@@ -62,15 +59,10 @@ sub ActionRow {
             $BulkFeature = 1;
         }
         else {
-            my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
             GROUP:
             for my $Group (@Groups) {
-                my $HasPermission = $GroupObject->PermissionCheck(
-                    UserID    => $Self->{UserID},
-                    GroupName => $Group,
-                    Type      => 'rw',
-                );
-                if ($HasPermission) {
+                next GROUP if !$LayoutObject->{"UserIsGroup[$Group]"};
+                if ( $LayoutObject->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
                     last GROUP;
                 }
@@ -168,6 +160,12 @@ sub ActionRow {
         }
     }
 
+    # init for table control
+    $LayoutObject->Block(
+        Name => 'DocumentReadyStart',
+        Data => \%Param,
+    );
+
     my $Output = $LayoutObject->Output(
         TemplateFile => 'AgentTicketOverviewPreview',
         Data         => \%Param,
@@ -185,11 +183,11 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for my $Item (qw(TicketIDs PageShown StartHit)) {
-        if ( !$Param{$Item} ) {
+    for (qw(TicketIDs PageShown StartHit)) {
+        if ( !$Param{$_} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $Item!",
+                Message  => "Need $_!"
             );
             return;
         }
@@ -210,15 +208,10 @@ sub Run {
             $BulkFeature = 1;
         }
         else {
-            my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
             GROUP:
             for my $Group (@Groups) {
-                my $HasPermission = $GroupObject->PermissionCheck(
-                    UserID    => $Self->{UserID},
-                    GroupName => $Group,
-                    Type      => 'rw',
-                );
-                if ($HasPermission) {
+                next GROUP if !$LayoutObject->{"UserIsGroup[$Group]"};
+                if ( $LayoutObject->{"UserIsGroup[$Group]"} eq 'Yes' ) {
                     $BulkFeature = 1;
                     last GROUP;
                 }
@@ -247,22 +240,6 @@ sub Run {
     my $CounterOnSite = 0;
     my @TicketIDsShown;
 
-    my $ArticleObject             = $Kernel::OM->Get('Kernel::System::Ticket::Article');
-    my $PreviewArticleSenderTypes = $ConfigObject->Get('Ticket::Frontend::Overview::PreviewArticleSenderTypes');
-    my %PreviewArticleSenderTypeIDs;
-    if ( IsHashRefWithData($PreviewArticleSenderTypes) ) {
-
-        KEY:
-        for my $Key ( %{$PreviewArticleSenderTypes} ) {
-            next KEY if !$PreviewArticleSenderTypes->{$Key};
-
-            my $ID = $ArticleObject->ArticleSenderTypeLookup( SenderType => $Key );
-            if ($ID) {
-                $PreviewArticleSenderTypeIDs{$ID} = 1;
-            }
-        }
-    }
-
     # check if there are tickets to show
     if ( scalar @{ $Param{TicketIDs} } ) {
 
@@ -275,12 +252,11 @@ sub Run {
             {
                 push @TicketIDsShown, $TicketID;
                 my $Output = $Self->_Show(
-                    TicketID                    => $TicketID,
-                    Counter                     => $CounterOnSite,
-                    Bulk                        => $BulkFeature,
-                    Config                      => $Param{Config},
-                    Output                      => $Param{Output} || '',
-                    PreviewArticleSenderTypeIDs => \%PreviewArticleSenderTypeIDs,
+                    TicketID => $TicketID,
+                    Counter  => $CounterOnSite,
+                    Bulk     => $BulkFeature,
+                    Config   => $Param{Config},
+                    Output   => $Param{Output} || '',
                 );
                 $CounterOnSite++;
                 if ( !$Param{Output} ) {
@@ -291,16 +267,6 @@ sub Run {
                 }
             }
         }
-
-        # send data to JS
-        $LayoutObject->AddJSData(
-            Key   => 'ReplyFieldsFormID',
-            Value => $Self->{ReplyFieldsFormID},
-        );
-        $LayoutObject->AddJSData(
-            Key   => 'ActionRowTickets',
-            Value => $Self->{ActionRowTickets},
-        );
     }
     else {
         $LayoutObject->Block( Name => 'NoTicketFound' );
@@ -338,11 +304,12 @@ sub _Show {
     if ( !$Param{TicketID} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
-            Message  => 'Need TicketID!',
+            Message  => 'Need TicketID!'
         );
         return;
     }
 
+    # get layout object
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     # check if bulk feature is enabled
@@ -353,64 +320,46 @@ sub _Show {
         );
     }
 
+    # get config object
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
-    my $PreviewArticleLimit = int $ConfigObject->Get('Ticket::Frontend::Overview::PreviewArticleLimit') || 5;
+    # collect params for ArticleGet
+    my %ArticleGetParams = (
+        TicketID      => $Param{TicketID},
+        UserID        => $Self->{UserID},
+        DynamicFields => 0,
+        Order         => 'DESC',
+        Limit         => $ConfigObject->Get('Ticket::Frontend::Overview::PreviewArticleLimit') || 5,
+    );
 
-    my $TicketObject  = $Kernel::OM->Get('Kernel::System::Ticket');
-    my $ArticleObject = $Kernel::OM->Get('Kernel::System::Ticket::Article');
+    # check if certain article sender types should be excluded from preview
+    my $PreviewArticleSenderTypes = $ConfigObject->Get('Ticket::Frontend::Overview::PreviewArticleSenderTypes');
+    my @ActiveArticleSenderTypes;
+    if ( ref $PreviewArticleSenderTypes eq 'HASH' ) {
+        @ActiveArticleSenderTypes = grep { $PreviewArticleSenderTypes->{$_} == 1 } keys %{$PreviewArticleSenderTypes};
+    }
+
+    # if a list of active article sender types has been determined, add them to params hash
+    if (@ActiveArticleSenderTypes) {
+        $ArticleGetParams{ArticleSenderType} = \@ActiveArticleSenderTypes;
+    }
+
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
+    # get last 5 articles
+    my @ArticleBody = $TicketObject->ArticleGet(
+        %ArticleGetParams,
+    );
+    my %Article = %{ $ArticleBody[0] || {} };
+    my $ArticleCount = scalar @ArticleBody;
 
     my %Ticket = $TicketObject->TicketGet(
         TicketID      => $Param{TicketID},
         DynamicFields => 0,
     );
 
-    # Get configured number of last articles.
-    my @Articles = $ArticleObject->ArticleList(
-        TicketID => $Param{TicketID},
-    );
-    @Articles = reverse @Articles;
-    if ( scalar @Articles > $PreviewArticleLimit ) {
-        @Articles = @Articles[ 0 .. $PreviewArticleLimit - 1 ];
-    }
-
-    my @ArticleBody;
-    my %Article;
-
-    ARTICLE:
-    for my $Article (@Articles) {
-
-        # Check if certain article sender types should be excluded from preview.
-        next ARTICLE
-            if IsHashRefWithData( $Param{PreviewArticleSenderTypeIDs} )
-            && !$Param{PreviewArticleSenderTypeIDs}->{ $Article->{SenderTypeID} };
-
-        my $ArticleBackendObject = $ArticleObject->BackendForArticle( %{$Article} );
-
-        my %ArticleData = $ArticleBackendObject->ArticleGet(
-            TicketID      => $Param{TicketID},
-            ArticleID     => $Article->{ArticleID},
-            DynamicFields => 0,
-        );
-        %ArticleData = ( %ArticleData, %Ticket );
-
-        my %ArticleFields = $LayoutObject->ArticleFields(
-            TicketID  => $Param{TicketID},
-            ArticleID => $Article->{ArticleID},
-        );
-
-        $ArticleData{ArticleFields} = \%ArticleFields;
-
-        push @ArticleBody, \%ArticleData;
-
-        if ( !%Article ) {
-            %Article = %ArticleData;
-        }
-    }
-
-    my $ArticleCount = scalar @ArticleBody;
-
-    # Fallback for tickets without articles: get at least basic ticket data.
+    # Fallback for tickets without articles: get at least basic ticket data
     if ( !%Article ) {
         %Article = %Ticket;
         if ( !$Article{Title} ) {
@@ -427,11 +376,6 @@ sub _Show {
     );
     %Article = ( %UserInfo, %Article );
 
-    # get responsible info from ticket
-    my %TicketResponsible = $Kernel::OM->Get('Kernel::System::User')->GetUserData(
-        UserID => $Ticket{ResponsibleID},
-    );
-
     # create human age
     $Article{Age} = $LayoutObject->CustomerAge(
         Age   => $Article{Age},
@@ -448,9 +392,8 @@ sub _Show {
     );
 
     $Param{StandardResponsesStrg} = $LayoutObject->BuildSelection(
-        Name  => 'ResponseID',
-        Class => 'Modernize',
-        Data  => $StandardTemplates{Answer} || {},
+        Name => 'ResponseID',
+        Data => $StandardTemplates{Answer} || {},
     );
 
     # customer info
@@ -585,16 +528,6 @@ sub _Show {
         },
     );
 
-    $LayoutObject->Block(
-        Name => 'OwnerResponsible',
-        Data => {
-            Owner               => $UserInfo{'UserLogin'},
-            OwnerFullname       => $UserInfo{'UserFullname'},
-            Responsible         => $TicketResponsible{'UserLogin'},
-            ResponsibleFullname => $TicketResponsible{'UserFullname'},
-        },
-    );
-
     # if "Actions per Ticket" (Inline Action Row) is active
     if ( $Param{Config}->{TicketActionsPerTicket} ) {
         $LayoutObject->Block(
@@ -688,8 +621,7 @@ sub _Show {
                 # run module
                 my @Data = $Object->Check(
                     Article => \%Article,
-                    %Param,
-                    Config => $Jobs{$Job},
+                    %Param, Config => $Jobs{$Job}
                 );
 
                 for my $DataRef (@Data) {
@@ -709,8 +641,7 @@ sub _Show {
                 # filter option
                 $Object->Filter(
                     Article => \%Article,
-                    %Param,
-                    Config => $Jobs{$Job},
+                    %Param, Config => $Jobs{$Job}
                 );
             }
         }
@@ -719,11 +650,7 @@ sub _Show {
     # create output
     $LayoutObject->Block(
         Name => 'AgentAnswer',
-        Data => {
-            %Param,
-            %Article,
-            %AclAction,
-        },
+        Data => { %Param, %Article, %AclAction },
     );
     if (
         $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
@@ -745,11 +672,7 @@ sub _Show {
             if ($Access) {
                 $LayoutObject->Block(
                     Name => 'AgentAnswerCompose',
-                    Data => {
-                        %Param,
-                        %Article,
-                        %AclAction,
-                    },
+                    Data => { %Param, %Article, %AclAction },
                 );
             }
         }
@@ -778,11 +701,7 @@ sub _Show {
         if ($Access) {
             $LayoutObject->Block(
                 Name => 'AgentAnswerPhoneOutbound',
-                Data => {
-                    %Param,
-                    %Article,
-                    %AclAction,
-                },
+                Data => { %Param, %Article, %AclAction },
             );
         }
     }
@@ -791,10 +710,7 @@ sub _Show {
     if ( $ConfigObject->Get('Ticket::Type') ) {
         $LayoutObject->Block(
             Name => 'Type',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
     }
 
@@ -802,18 +718,12 @@ sub _Show {
     if ( $ConfigObject->Get('Ticket::Service') && $Article{Service} ) {
         $LayoutObject->Block(
             Name => 'Service',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
         if ( $Article{SLA} ) {
             $LayoutObject->Block(
                 Name => 'SLA',
-                Data => {
-                    %Param,
-                    %Article,
-                },
+                Data => { %Param, %Article },
             );
         }
     }
@@ -822,10 +732,7 @@ sub _Show {
     if ( defined $Article{CustomerID} ) {
         $LayoutObject->Block(
             Name => 'CustomerID',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
 
         # test access to frontend module
@@ -855,92 +762,71 @@ sub _Show {
 
         $LayoutObject->Block(
             Name => $CustomerIDBlock,
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
 
         if ( defined $Article{CustomerName} ) {
             $LayoutObject->Block(
                 Name => 'CustomerName',
-                Data => {
-                    %Param,
-                    %Article,
-                },
+                Data => { %Param, %Article },
             );
         }
     }
 
     # show first response time if needed
     if ( defined $Article{FirstResponseTime} ) {
-        $Article{FirstResponseTimeHuman} = $LayoutObject->CustomerAge(
-            Age                => $Article{FirstResponseTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{FirstResponseTimeHuman} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{FirstResponseTime},
+            Space => ' ',
         );
-        $Article{FirstResponseTimeWorkingTime} = $LayoutObject->CustomerAge(
-            Age                => $Article{FirstResponseTimeWorkingTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{FirstResponseTimeWorkingTime} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{FirstResponseTimeWorkingTime},
+            Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{FirstResponseTime} ) {
-            $Article{FirstResponseTimeClass} = 'Warning';
+            $Article{FirstResponseTimeClass} = 'Warning'
         }
         $LayoutObject->Block(
             Name => 'FirstResponseTime',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
     }
 
     # show update time if needed
     if ( defined $Article{UpdateTime} ) {
-        $Article{UpdateTimeHuman} = $LayoutObject->CustomerAge(
-            Age                => $Article{UpdateTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{UpdateTimeHuman} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{UpdateTime},
+            Space => ' ',
         );
-        $Article{UpdateTimeWorkingTime} = $LayoutObject->CustomerAge(
-            Age                => $Article{UpdateTimeWorkingTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{UpdateTimeWorkingTime} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{UpdateTimeWorkingTime},
+            Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{UpdateTime} ) {
-            $Article{UpdateTimeClass} = 'Warning';
+            $Article{UpdateTimeClass} = 'Warning'
         }
         $LayoutObject->Block(
             Name => 'UpdateTime',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
     }
 
     # show solution time if needed
     if ( defined $Article{SolutionTime} ) {
-        $Article{SolutionTimeHuman} = $LayoutObject->CustomerAge(
-            Age                => $Article{SolutionTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{SolutionTimeHuman} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{SolutionTime},
+            Space => ' ',
         );
-        $Article{SolutionTimeWorkingTime} = $LayoutObject->CustomerAge(
-            Age                => $Article{SolutionTimeWorkingTime},
-            TimeShowAlwaysLong => 1,
-            Space              => ' ',
+        $Article{SolutionTimeWorkingTime} = $LayoutObject->CustomerAgeInHours(
+            Age   => $Article{SolutionTimeWorkingTime},
+            Space => ' ',
         );
         if ( 60 * 60 * 1 > $Article{SolutionTime} ) {
-            $Article{SolutionTimeClass} = 'Warning';
+            $Article{SolutionTimeClass} = 'Warning'
         }
         $LayoutObject->Block(
             Name => 'SolutionTime',
-            Data => {
-                %Param,
-                %Article,
-            },
+            Data => { %Param, %Article },
         );
     }
 
@@ -972,7 +858,7 @@ sub _Show {
             ObjectID           => $Param{TicketID},
         );
 
-        next DYNAMICFIELD if !defined $Value;
+        next DYNAMICFIELD if ( !defined $Value );
 
         $Counter++;
 
@@ -1097,156 +983,286 @@ sub _Show {
 
     if (@ArticleBody) {
 
-        # check if the first article should be displayed as expanded, that is visible for the related customer
-        my $PreviewIsVisibleForCustomerExpanded
-            = $ConfigObject->Get('Ticket::Frontend::Overview::PreviewIsVisibleForCustomerExpanded') || 0;
+        # check if a certain article type should be displayed as expanded
+        my $PreviewArticleTypeExpanded = $ConfigObject->Get('Ticket::Frontend::Overview::PreviewArticleTypeExpanded')
+            || '';
 
-        # if a certain article type should be shown as expanded, set the last article of this type as active
-        if ($PreviewIsVisibleForCustomerExpanded) {
+        # if a certain article type should be shown as expanded, set the
+        # last article of this type as active
+        if ($PreviewArticleTypeExpanded) {
 
             my $ClassCount = 0;
-            ARTICLEITEM:
+            ARTICLE_ITEM:
             for my $ArticleItem (@ArticleBody) {
+                next ARTICLE_ITEM if !$ArticleItem;
 
-                next ARTICLEITEM if !$ArticleItem;
-                next ARTICLEITEM if !IsHashRefWithData($ArticleItem);
-                next ARTICLEITEM if !$ArticleItem->{IsVisibleForCustomer};
+                # check if current article type should be shown as expanded
+                if ( $ArticleItem->{ArticleType} eq $PreviewArticleTypeExpanded ) {
+                    $ArticleItem->{Class} = 'Active';
+                    last ARTICLE_ITEM;
+                }
 
-                $ArticleItem->{Class} = 'Active';
-                last ARTICLEITEM;
+                # otherwise display the last article in the list as expanded (default)
+                elsif ( $ClassCount == $#ArticleBody ) {
+                    $ArticleBody[0]->{Class} = 'Active';
+                }
+                $ClassCount++;
             }
         }
 
-        # Display the last article in the list as expanded (default).
+        # otherwise display the last article in the list as expanded (default)
         else {
-
+            # find latest not seen article
             my $ArticleSelected;
             my $IgnoreSystemSender = $ConfigObject->Get('Ticket::NewArticleIgnoreSystemSender');
 
-            ARTICLEITEM:
+            ARTICLE:
             for my $ArticleItem (@ArticleBody) {
 
+                my %ArticleFlags = $TicketObject->ArticleFlagGet(
+                    ArticleID => $ArticleItem->{ArticleID},
+                    UserID    => $Self->{UserID},
+                );
+
                 # ignore system sender type
-                next ARTICLEITEM if $IgnoreSystemSender && $ArticleItem->{SenderType} eq 'system';
+                next ARTICLE
+                    if $IgnoreSystemSender
+                    && $ArticleItem->{SenderType} eq 'system';
+
+                # ignore already seen articles
+                next ARTICLE if $ArticleFlags{Seen};
 
                 $ArticleItem->{Class} = 'Active';
                 $ArticleSelected = 1;
-                last ARTICLEITEM;
+                last ARTICLE;
             }
 
             # set selected article
             if ( !$ArticleSelected ) {
-                $ArticleBody[0]->{Class} = 'Active';
+
+                # set last customer article as selected article
+                ARTICLETMP:
+                for my $ArticleTmp (@ArticleBody) {
+                    if ( $ArticleTmp->{SenderType} eq 'customer' ) {
+                        $ArticleTmp->{Class} = 'Active';
+                        $ArticleSelected = 1;
+                        last ARTICLETMP;
+                    }
+                }
+                if ( !$ArticleSelected ) {
+                    $ArticleBody[0]->{Class} = 'Active';
+                }
             }
         }
 
         $LayoutObject->Block(
             Name => 'ArticlesPreviewArea',
-            Data => {
-                %Param,
-                %Article,
-                %AclAction,
-            },
+            Data => { %Param, %Article, %AclAction },
         );
     }
 
-    my $CommunicationChannelObject = $Kernel::OM->Get('Kernel::System::CommunicationChannel');
-
-    # Save communication channel data to improve performance.
-    my %CommunicationChannelData;
-
     # show inline article
     for my $ArticleItem ( reverse @ArticleBody ) {
 
-        $ArticleItem->{Body} = $LayoutObject->ArticlePreview(
-            TicketID   => $ArticleItem->{TicketID},
-            ArticleID  => $ArticleItem->{ArticleID},
-            ResultType => 'plain',
+        # check if just a only html email
+        my $MimeTypeText = $LayoutObject->CheckMimeType(
+            %{$ArticleItem},
+            Action => 'AgentTicketZoom',
         );
+        if ($MimeTypeText) {
+            $ArticleItem->{BodyNote} = $MimeTypeText;
+            $ArticleItem->{Body}     = '';
+        }
+        else {
 
-        # html quoting
-        $ArticleItem->{Body} = $LayoutObject->Ascii2Html(
-            NewLine         => $Param{Config}->{DefaultViewNewLine} || 90,
-            Text            => $ArticleItem->{Body},
-            VMax            => $Param{Config}->{DefaultPreViewLines} || 25,
-            LinkFeature     => 1,
-            HTMLResultMode  => 1,
-            StripEmptyLines => $Param{Config}->{StripEmptyLines},
-        );
-
-        # Include some information about communication channel.
-        if ( !$CommunicationChannelData{ $ArticleItem->{CommunicationChannelID} } ) {
-
-            # Communication channel display name is part of the configuration.
-            my %CommunicationChannel = $CommunicationChannelObject->ChannelGet(
-                ChannelID => $ArticleItem->{CommunicationChannelID},
+            # html quoting
+            $ArticleItem->{Body} = $LayoutObject->Ascii2Html(
+                NewLine => $Param{Config}->{DefaultViewNewLine}  || 90,
+                Text    => $ArticleItem->{Body},
+                VMax    => $Param{Config}->{DefaultPreViewLines} || 25,
+                LinkFeature     => 1,
+                HTMLResultMode  => 1,
+                StripEmptyLines => $Param{Config}->{StripEmptyLines},
             );
-
-            # Presence of communication channel object indicates its validity.
-            my $ChannelObject = $CommunicationChannelObject->ChannelObjectGet(
-                ChannelID => $ArticleItem->{CommunicationChannelID},
-            );
-
-            $CommunicationChannelData{ $ArticleItem->{CommunicationChannelID} } = {
-                ChannelDisplayName => $CommunicationChannel{DisplayName},
-                ChannelInvalid     => !$ChannelObject,
-            };
         }
 
-        my @ArticleActions = $LayoutObject->ArticleActions(
-            TicketID  => $ArticleItem->{TicketID},
-            ArticleID => $ArticleItem->{ArticleID},
-            UserID    => $Self->{UserID},
-            Type      => 'Static',
+        $ArticleItem->{Subject} = $TicketObject->TicketSubjectClean(
+            TicketNumber => $ArticleItem->{TicketNumber},
+            Subject      => $ArticleItem->{Subject} || '',
         );
 
-        # Remove the 'Mark' action, which is implemented only in AgentTicketZoom.
-        @ArticleActions = grep { $_->{Name} ne 'Mark' } @ArticleActions;
-
         $LayoutObject->Block(
             Name => 'ArticlePreview',
             Data => {
                 %{$ArticleItem},
-                %{ $CommunicationChannelData{ $ArticleItem->{CommunicationChannelID} } },
-                MenuItems => \@ArticleActions,
+                Class => $ArticleItem->{Class},
             },
         );
 
-        # check if compose link should be shown
-        if (
-            $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
-            && (
-                !defined $AclAction{AgentTicketCompose}
-                || $AclAction{AgentTicketCompose}
-            )
-            )
-        {
-            my $Access = 1;
-            my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
-            if ( $Config->{Permission} ) {
-                my $Ok = $TicketObject->Permission(
-                    Type     => $Config->{Permission},
-                    TicketID => $Article{TicketID},
-                    UserID   => $Self->{UserID},
-                    LogNo    => 1,
-                );
-                if ( !$Ok ) {
-                    $Access = 0;
-                }
-            }
-            if ( $Config->{RequiredLock} ) {
-                my $Locked = $TicketObject->LockIsTicketLocked(
-                    TicketID => $Article{TicketID},
-                );
-                if ($Locked) {
-                    my $AccessOk = $TicketObject->OwnerCheck(
+        # show actions
+        if ( $ArticleItem->{ArticleType} !~ /^(note|email-noti)/i ) {
+
+            # check if compose link should be shown
+            if (
+                $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
+                && (
+                    !defined $AclAction{AgentTicketCompose}
+                    || $AclAction{AgentTicketCompose}
+                )
+                )
+            {
+                my $Access = 1;
+                my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
+                if ( $Config->{Permission} ) {
+                    my $Ok = $TicketObject->Permission(
+                        Type     => $Config->{Permission},
                         TicketID => $Article{TicketID},
-                        OwnerID  => $Self->{UserID},
+                        UserID   => $Self->{UserID},
+                        LogNo    => 1,
                     );
-                    if ( !$AccessOk ) {
+                    if ( !$Ok ) {
                         $Access = 0;
                     }
                 }
+                if ( $Config->{RequiredLock} ) {
+                    my $Locked = $TicketObject->LockIsTicketLocked(
+                        TicketID => $Article{TicketID},
+                    );
+                    if ($Locked) {
+                        my $AccessOk = $TicketObject->OwnerCheck(
+                            TicketID => $Article{TicketID},
+                            OwnerID  => $Self->{UserID},
+                        );
+                        if ( !$AccessOk ) {
+                            $Access = 0;
+                        }
+                    }
+                }
+                if ($Access) {
+                    $LayoutObject->Block(
+                        Name => 'ArticlePreviewActionRow',
+                        Data => {
+                            %{$ArticleItem}, %AclAction,
+                        },
+                    );
+
+                    # fetch all std. responses
+                    my %StandardTemplates = $QueueObject->QueueStandardTemplateMemberList(
+                        QueueID       => $Article{QueueID},
+                        TemplateTypes => 1,
+                    );
+
+                    my %StandardResponses;
+                    if ( IsHashRefWithData( $StandardTemplates{Answer} ) ) {
+                        %StandardResponses = %{ $StandardTemplates{Answer} };
+                    }
+
+                    # get StandardResponsesStrg
+                    # get revers StandardResponse because we need to sort by Values
+                    # from %ReverseStandardResponseHash we get value of Key by %StandardResponse Value
+                    # and @StandardResponseArray is created as array of hashes with elements Key and Value
+
+                    my %ReverseStandardResponseHash = reverse %StandardResponses;
+                    my @StandardResponseArray       = map {
+                        {
+                            Key   => $ReverseStandardResponseHash{$_},
+                            Value => $_
+                        }
+                    } sort values %StandardResponses;
+
+                    unshift(
+                        @StandardResponseArray,
+                        {
+                            Key   => '0',
+                            Value => '- '
+                                . $LayoutObject->{LanguageObject}->Translate('Reply')
+                                . ' -',
+                            Selected => 1,
+                        }
+                    );
+
+                    # build html string
+                    my $StandardResponsesStrg = $LayoutObject->BuildSelection(
+                        Name => 'ResponseID',
+                        ID   => 'ResponseID' . $ArticleItem->{ArticleID},
+                        Data => \@StandardResponseArray,
+                    );
+
+                    $LayoutObject->Block(
+                        Name => 'ArticlePreviewActionRowItem',
+                        Data => {
+                            %{$ArticleItem},
+                            StandardResponsesStrg => $StandardResponsesStrg,
+                            Name                  => Translatable('Reply'),
+                            Class                 => 'AsPopup',
+                            Action                => 'AgentTicketCompose',
+                            FormID                => 'Reply' . $ArticleItem->{ArticleID},
+                        },
+                    );
+
+                    # check if reply all is needed
+                    my $Recipients = '';
+                    KEY:
+                    for my $Key (qw(From To Cc)) {
+                        next KEY if !$ArticleItem->{$Key};
+                        if ($Recipients) {
+                            $Recipients .= ', ';
+                        }
+                        $Recipients .= $ArticleItem->{$Key};
+                    }
+                    my $RecipientCount = 0;
+                    if ($Recipients) {
+                        my $EmailParser = Kernel::System::EmailParser->new(
+                            %{$Self},
+                            Mode => 'Standalone',
+                        );
+                        my @Addresses = $EmailParser->SplitAddressLine( Line => $Recipients );
+                        ADDRESS:
+                        for my $Address (@Addresses) {
+                            my $Email = $EmailParser->GetEmailAddress( Email => $Address );
+                            next ADDRESS if !$Email;
+                            my $IsLocal
+                                = $Kernel::OM->Get('Kernel::System::SystemAddress')->SystemAddressIsLocalAddress(
+                                Address => $Email,
+                                );
+                            next ADDRESS if $IsLocal;
+                            $RecipientCount++;
+                        }
+                    }
+                    if ( $RecipientCount > 1 ) {
+
+                        # get StandardResponsesStrg
+                        shift(@StandardResponseArray);
+                        unshift(
+                            @StandardResponseArray,
+                            {
+                                Key   => '0',
+                                Value => '- '
+                                    . $LayoutObject->{LanguageObject}->Translate('Reply All')
+                                    . ' -',
+                                Selected => 1,
+                            }
+                        );
+                        $StandardResponsesStrg = $LayoutObject->BuildSelection(
+                            Name => 'ResponseID',
+                            ID   => 'ResponseIDAll' . $ArticleItem->{ArticleID},
+                            Data => \@StandardResponseArray,
+                        );
+
+                        $LayoutObject->Block(
+                            Name => 'ArticlePreviewActionRowItem',
+                            Data => {
+                                %{$ArticleItem},
+                                StandardResponsesStrg => $StandardResponsesStrg,
+                                Name                  => Translatable('Reply All'),
+                                Class                 => 'AsPopup',
+                                Action                => 'AgentTicketCompose',
+                                FormID                => 'ReplyAll' . $ArticleItem->{ArticleID},
+                                ReplyAll              => 1,
+                            },
+                        );
+                    }
+                }
             }
         }
     }
@@ -1254,17 +1270,13 @@ sub _Show {
     # add action items as js
     if ( @ActionItems && !$Param{Config}->{TicketActionsPerTicket} ) {
 
-        # replace TT directives from string with values
-        for my $ActionItem (@ActionItems) {
-            $ActionItem->{Link} = $LayoutObject->Output(
-                Template => $ActionItem->{Link},
-                Data     => {
-                    TicketID => $Article{TicketID},
-                },
-            );
-        }
-
-        $Self->{ActionRowTickets}->{ $Param{TicketID} } = $LayoutObject->JSONEncode( Data => \@ActionItems );
+        $LayoutObject->Block(
+            Name => 'DocumentReadyActionRowAdd',
+            Data => {
+                TicketID => $Param{TicketID},
+                Data     => \@ActionItems,
+            },
+        );
     }
 
     # create & return output
@@ -1278,5 +1290,4 @@ sub _Show {
     );
     return \$Output;
 }
-
 1;
