@@ -1,5 +1,4 @@
 # --
-# Kernel/System/CSV.pm - all csv functions
 # Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -56,8 +55,9 @@ sub new {
 Returns a csv formatted string based on a array with head data.
 
     $CSV = $CSVObject->Array2CSV(
-        Head => [ 'RowA', 'RowB', ],   # optional
-        Data => [
+        WithHeader => [ 'RowA', 'RowB', ],   # optional
+        Head       => [ 'RowA', 'RowB', ],   # optional
+        Data       => [
             [ 1, 4 ],
             [ 7, 3 ],
             [ 1, 9 ],
@@ -92,6 +92,10 @@ sub Array2CSV {
     if ( $Param{Data} ) {
         @Data = @{ $Param{Data} };
     }
+    my @WithHeader;
+    if ( $Param{WithHeader} ) {
+        @WithHeader = @{ $Param{WithHeader} };
+    }
 
     # get format
     $Param{Format} //= 'CSV';
@@ -118,7 +122,17 @@ sub Array2CSV {
         # We will try to determine the appropriate length for each column.
         my @ColumnLengths;
         my $Row = 0;
-        for my $DataRaw ( \@Head, @Data ) {
+
+        my @Rows = ( \@Head, @Data );
+
+        if ( scalar @WithHeader ) {
+
+            # Adds \@WithHeader to the beggining of @Rows, if not empty.
+            #    Otherwise it adds empty first row - see bug#12467.
+            unshift @Rows, \@WithHeader;
+        }
+
+        for my $DataRaw (@Rows) {
             COL:
             for my $Col ( 0 .. ( scalar @{ $DataRaw // [] } ) - 1 ) {
                 next COL if !defined( $DataRaw->[$Col] );
@@ -181,6 +195,12 @@ sub Array2CSV {
             }
         );
 
+        # set header if given
+        if (@WithHeader) {
+            my $Status = $CSV->combine(@WithHeader);
+            $Output .= $CSV->string() . "\n";
+        }
+
         # if we have head param fill in header
         if (@Head) {
             my $Status = $CSV->combine(@Head);
@@ -221,24 +241,14 @@ Returns an array with parsed csv data.
 sub CSV2Array {
     my ( $Self, %Param ) = @_;
 
-    # get separator
-    if ( !defined $Param{Separator} || $Param{Separator} eq '' ) {
-        $Param{Separator} = ';';
-    }
-
-    # get separator
-    if ( !defined $Param{Quote} ) {
-        $Param{Quote} = '"';
-    }
-
     # create new csv backend object
     my $CSV = Text::CSV->new(
         {
 
-            #            quote_char          => $Param{Quote},
-            #            escape_char         => $Param{Quote},
-            sep_char            => $Param{Separator},
-            eol                 => '',
+            quote_char => $Param{Quote} // '"',
+            escape_char => $Param{Quote}     || '"',
+            sep_char    => $Param{Separator} || ";",
+            eol         => '',
             always_quote        => 0,
             binary              => 1,
             keep_meta_info      => 0,
@@ -252,20 +262,25 @@ sub CSV2Array {
     # do some dos/unix file conversions
     $Param{String} =~ s/(\n\r|\r\r\n|\r\n|\r)/\n/g;
 
-    # if you change the split options, remember that each value can include \n
     my @Array;
-    my @Lines = split /$Param{Quote}\n/, $Param{String};
-    for my $Line (@Lines) {
-        if ( $CSV->parse( $Line . $Param{Quote} ) ) {
-            my @Fields = $CSV->fields();
-            push @Array, \@Fields;
-        }
-        else {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => 'Failed to parse line: ' . $CSV->error_input(),
-            );
-        }
+
+    # parse all CSV data line by line (allows newlines in data fields)
+    my $LineCounter = 1;
+    open my $FileHandle, '<', \$Param{String};    ## no critic
+    while ( my $ColRef = $CSV->getline($FileHandle) ) {
+        push @Array, $ColRef;
+        $LineCounter++;
+    }
+
+    # log error if occurred and exit
+    if ( !$CSV->eof() ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Failed to parse CSV line ' . $LineCounter
+                . ' (input: ' . $CSV->error_input()
+                . ', error: ' . $CSV->error_diag() . ')',
+        );
+        return;
     }
 
     return \@Array;
