@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::CloudService::Backend::Run;
@@ -19,7 +19,6 @@ our @ObjectDependencies = (
     'Kernel::System::Encode',
     'Kernel::System::JSON',
     'Kernel::System::Log',
-    'Kernel::System::OTRSBusiness',
     'Kernel::System::SystemData',
     'Kernel::System::WebUserAgent',
 );
@@ -28,16 +27,22 @@ our @ObjectDependencies = (
 
 Kernel::System::CloudService::Backend::Run - cloud service lib
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All functions for cloud service communication.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 create a CloudService object. Do not use it directly, instead use:
 
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $CloudServiceObject = $Kernel::OM->Get('Kernel::System::CloudService::Backend::Run');
 
 =cut
@@ -62,7 +67,7 @@ sub new {
     return $Self;
 }
 
-=head2 Request()
+=item Request()
 
 perform a cloud service communication and return result data
 
@@ -186,14 +191,10 @@ sub Request {
     # create config object
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
-    # If OTRSSTORM package is installed, system is able to do a Cloud request even if CloudService is disabled.
-    if ( !$Kernel::OM->Get('Kernel::System::OTRSBusiness')->OTRSSTORMIsInstalled() ) {
+    # check if cloud services are disabled
+    my $CloudServicesDisabled = $ConfigObject->Get('CloudServices::Disabled');
 
-        # check if cloud services are disabled
-        my $CloudServicesDisabled = $ConfigObject->Get('CloudServices::Disabled');
-
-        return if $CloudServicesDisabled;
-    }
+    return if $CloudServicesDisabled;
 
     # check needed stuff
     if ( !defined $Param{RequestData} ) {
@@ -271,8 +272,8 @@ sub Request {
         my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
 
         # check cache
-        my $CacheKey = "APIKey::" . ( $Self->{RegistrationData}->{APIKey} || '' )
-            . "::UniqueID::" . ( $Self->{RegistrationData}->{UniqueID} || '' );
+        my $CacheKey = "APIKey::" . $Self->{RegistrationData}->{APIKey} || ''
+            . "::UniqueID::" . $Self->{RegistrationData}->{UniqueID} || '';
         my $CacheContent = $CacheObject->Get(
             Type => 'RequestUniqueIDAuth',
             Key  => $CacheKey,
@@ -331,7 +332,7 @@ sub Request {
         },
     );
 
-    # Perform web service request.
+    # perform webservice request
     my %Response;
     TRY:
     for my $Try ( 1 .. 3 ) {
@@ -406,7 +407,7 @@ sub Request {
     return;
 }
 
-=head2 OperationResultGet()
+=item OperationResultGet()
 
     my $OperationResult = $CloudServiceObject->OperationResultGet(
         CloudService => 'Test',
@@ -521,13 +522,7 @@ sub OperationResultGet {
         }
         else {
 
-            if (
-                !defined $OperationResult->{InstanceName}
-                || $OperationResult->{InstanceName} ne $Param{InstanceName}
-                )
-            {
-                next RESULT;
-            }
+            next RESULT if $OperationResult->{InstanceName} ne $Param{InstanceName};
         }
 
         return $OperationResult;
@@ -555,12 +550,14 @@ sub OperationResultGet {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
