@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Admin::Article::StorageSwitch;
@@ -11,15 +11,13 @@ package Kernel::System::Console::Command::Admin::Article::StorageSwitch;
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::Console::BaseCommand);
-
-use Time::HiRes qw(usleep);
+use base qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
     'Kernel::Config',
-    'Kernel::System::DateTime',
     'Kernel::System::PID',
     'Kernel::System::Ticket',
+    'Kernel::System::Time',
 );
 
 sub Configure {
@@ -72,13 +70,13 @@ sub Configure {
     $Self->AdditionalHelp(<<"EOF");
 The <green>$Name</green> command migrates article data from one storage backend to another on the fly, for example from DB to FS:
 
- <green>otrs.Console.pl $Self->{Name} --target ArticleStorageFS</green>
+ <green>otrs.console.pl $Self->{Name} --target ArticleStorageFS</green>
 
 You can specify limits for the tickets migrated with <yellow>--tickets-closed-before-date</yellow> and <yellow>--tickets-closed-before-days</yellow>.
 
 To reduce load on the database for a running system, you can use the <yellow>--micro-sleep</yellow> parameter. The command will pause for the specified amount of microseconds after each ticket.
 
- <green>otrs.Console.pl $Self->{Name} --target ArticleStorageFS --micro-sleep 1000</green>
+ <green>otrs.console.pl $Self->{Name} --target ArticleStorageFS --micro-sleep 1000</green>
 EOF
     return;
 }
@@ -118,21 +116,17 @@ sub Run {
     elsif ( $Self->GetOption('tickets-closed-before-days') ) {
         my $Seconds = $Self->GetOption('tickets-closed-before-days') * 60 * 60 * 24;
 
-        my $OlderDTObject = $Kernel::OM->Create('Kernel::System::DateTime');
-        $OlderDTObject->Subtract( Seconds => $Seconds );
+        my $TimeStamp = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $Seconds;
+        $TimeStamp = $Kernel::OM->Get('Kernel::System::Time')->SystemTime2TimeStamp(
+            SystemTime => $TimeStamp,
+        );
 
         %SearchParams = (
             StateType                => 'Closed',
-            TicketCloseTimeOlderDate => $OlderDTObject->ToString(),
+            TicketCloseTimeOlderDate => $TimeStamp,
         );
     }
 
-    # If Archive system is enabled, take into account archived tickets as well.
-    # See bug#13945 (https://bugs.otrs.org/show_bug.cgi?id=13945).
-    if ( $Kernel::OM->Get('Kernel::Config')->{'Ticket::ArchiveSystem'} ) {
-        $SearchParams{ArchiveFlags} = [ 'y', 'n' ];
-    }
-
     my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
     my @TicketIDs = $TicketObject->TicketSearch(
