@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Dev::Tools::GenericInterface::DebugRead;
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 use utf8;
 
-use parent qw(Kernel::System::Console::BaseCommand);
+use base qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
     'Kernel::System::GenericInterface::DebugLog',
@@ -59,24 +59,17 @@ sub Configure {
     );
     $Self->AddOption(
         Name        => 'webservice-id',
-        Description => "Restriction on entries of a given web service id.",
+        Description => "Restriction on entries of a given webservice id.",
         Required    => 0,
         HasValue    => 1,
         ValueRegex  => qr/^\d+$/smx,
     );
     $Self->AddOption(
         Name        => 'with-data',
-        Description => "Restriction on entries of a given web service id.",
+        Description => "Restriction on entries of a given webservice id.",
         Required    => 0,
         HasValue    => 0,
     );
-    $Self->AddOption(
-        Name        => 'limit',
-        Description => "Specify result entries limit, default is 100.",
-        Required    => 0,
-        HasValue    => 1,
-        ValueRegex  => qr/^\d+$/smx,
-    );
 
     return;
 }
@@ -92,7 +85,6 @@ sub Run {
     my $RemoteIP          = $Self->GetOption('remote-ip');
     my $WebserviceID      = $Self->GetOption('webservice-id');
     my $WithData          = $Self->GetOption('with-data');
-    my $Limit             = $Self->GetOption('limit');
 
     # create needed objects
     my $DebugLogObject = $Kernel::OM->Get('Kernel::System::GenericInterface::DebugLog');
@@ -107,7 +99,6 @@ sub Run {
         RemoteIP          => $RemoteIP,
         WebserviceID      => $WebserviceID,
         WithData          => $WithData,
-        Limit             => $Limit,
     );
 
     if ( ref $LogData eq 'ARRAY' ) {
