@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -57,6 +57,12 @@ sub Configure {
         HasValue    => 1,
         ValueRegex  => qr/.*/smx,
     );
+    $Self->AddOption(
+        Name        => 'verbose',
+        Description => "Show details for all tests, not just failing.",
+        Required    => 0,
+        HasValue    => 0,
+    );
 }
 
 sub Run {
@@ -74,6 +80,7 @@ sub Run {
         Directory => $Self->GetOption('directory')  || '',
         Product   => $Self->GetOption('product')    || '',
         SubmitURL => $Self->GetOption('submit-url') || '',
+        Verbose   => $Self->GetOption('verbose')    || '',
     );
 
     if ($FunctionResult) {
@@ -83,15 +90,3 @@ sub Run {
 }
 
 1;
-
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
