@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Internal::BashCompletion;
@@ -13,7 +13,7 @@ use warnings;
 
 use Kernel::System::Console::InterfaceConsole;
 
-use parent qw(Kernel::System::Console::BaseCommand Kernel::System::Console::Command::List);
+use base qw(Kernel::System::Console::BaseCommand Kernel::System::Console::Command::List);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -69,7 +69,7 @@ sub Run {
         # We need to extract the command name from the command line if present.
         my $CompLine = $ENV{COMP_LINE};
         if ( !$CompLine || !$CompLine =~ m/otrs\.Console\.pl/ ) {
-            $Self->ExitCodeError();
+            $Self->ExitCodeError()
         }
         $CompLine =~ s/.*otrs\.Console\.pl\s*//xms;
         my @Elements = split( m/\s+/, $CompLine );
