@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Maint::Daemon::Summary;
@@ -13,7 +13,7 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsArrayRefWithData);
 
-use parent qw(Kernel::System::Console::BaseCommand);
+use base qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -22,7 +22,7 @@ our @ObjectDependencies = (
 sub Configure {
     my ( $Self, %Param ) = @_;
 
-    $Self->Description('Show a summary of one or all daemon modules.');
+    $Self->Description('Shows a summary of one or all daemon modules.');
 
     $Self->AddArgument(
         Name        => 'daemon-name',
@@ -84,10 +84,10 @@ sub Run {
     my $DaemonName = $Self->GetArgument('daemon-name');
 
     if ($DaemonName) {
-        $Self->Print("\n<yellow>Gathering summary for '$DaemonName'...</yellow>\n\n");
+        $Self->Print("<yellow>Gathering '$DaemonName' daemon summary...</yellow>\n\n");
     }
     else {
-        $Self->Print("\n<yellow>Gathering summary for all daemons...</yellow>\n\n");
+        $Self->Print("<yellow>Gathering all daemons summary...</yellow>\n\n");
     }
 
     # get daemon modules from SysConfig
@@ -161,57 +161,42 @@ sub _FormatOutput {
     for my $Summary (@DaemonSummary) {
 
         # set header message
-        $Output .= '  <yellow>' . $Summary->{Header} . "</yellow>\n";
+        $Output .= '  ' . $Summary->{Header} . "\n";
 
         # if there is no data to display, show empty message
         if ( !IsArrayRefWithData( $Summary->{Data} ) ) {
-            $Output .= '    ' . ( $Summary->{NoDataMessage} || '' ) . "\n\n";
+            $Output .= '    ' . ( $Summary->{NoDataMesssage} || '' ) . "\n\n";
 
             next SUMMARY;
         }
 
-        my @TableHeader;
-        my @TableBody;
-
-        # generate table header
+        # output the table header
+        $Output .= '    ';
         for my $Column ( @{ $Summary->{Column} } ) {
-            push @TableHeader, $Column->{DisplayName};
+
+            my $Size  = $Column->{Size};
+            my $Value = $Column->{DisplayName};
+
+            $Output .= ' ' . sprintf '%-*s', $Size, uc $Value;
         }
+        $Output .= "\n";
 
-        # generate table body
+        # output the table body
         for my $DataRow ( @{ $Summary->{Data} } ) {
-
-            my @BodyRow;
-
+            $Output .= '    ';
             for my $Column ( @{ $Summary->{Column} } ) {
 
+                my $Size = $Column->{Size};
                 my $Value = $DataRow->{ $Column->{Name} } // '';
 
-                if ( $Value eq 'Success' ) {
-                    $Value = "<green>$Value</green>";
+                if ( length $Value >= $Size ) {
+                    $Value = substr( $Value, 0, $Size - 4 ) . '...';
                 }
-                elsif ( $Value eq 'N/A' ) {
-                    $Value = "<yellow>$Value</yellow>";
-                }
-                elsif ( $Value eq 'Fail' ) {
-                    $Value = "<red>$Value</red>";
-                }
-
-                push @BodyRow, $Value;
+                $Output .= ' ' . sprintf '%-*s', $Size, $Value;
             }
-
-            push @TableBody, \@BodyRow;
+            $Output .= "\n";
         }
-
-        my $TableOutput = $Self->TableOutput(
-            TableData => {
-                Header => \@TableHeader,
-                Body   => \@TableBody,
-            },
-            Indention => 2,
-        );
-
-        $Output .= "$TableOutput\n";
+        $Output .= "\n";
     }
 
     return $Output // '';
@@ -245,5 +230,4 @@ sub _DaemonSort {
     # otherwise do a numerical comparison with the framework daemons
     return $DefaultDaemons{$a} <=> $DefaultDaemons{$b};
 }
-
 1;
