@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Maint::Registration::UpdateSend;
@@ -11,13 +11,13 @@ package Kernel::System::Console::Command::Maint::Registration::UpdateSend;
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::Console::BaseCommand);
+use base qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
-    'Kernel::System::DateTime',
     'Kernel::Config',
     'Kernel::System::Registration',
     'Kernel::System::SystemData',
+    'Kernel::System::Time',
 );
 
 sub Configure {
@@ -33,14 +33,6 @@ sub Configure {
         ValueRegex  => qr/.*/smx,
     );
 
-    $Self->AddOption(
-        Name        => 'debug',
-        Description => "Output debug information while running.",
-        Required    => 0,
-        HasValue    => 0,
-        ValueRegex  => qr/.*/smx,
-    );
-
     return;
 }
 
@@ -67,33 +59,31 @@ sub Run {
         return $Self->ExitCodeOk();
     }
 
-    my $NextUpdateSystemTime;
+    my $NextUpdateSystemTime = 0;
+
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
 
     # if there is a defined NextUpdeTime convert it system time
     if ( $RegistrationData{NextUpdateTime} ) {
-        $NextUpdateSystemTime = $Kernel::OM->Create(
-            'Kernel::System::DateTime',
-            ObjectParams => {
-                String => $RegistrationData{NextUpdateTime},
-            },
+        $NextUpdateSystemTime = $TimeObject->TimeStamp2SystemTime(
+            String => $RegistrationData{NextUpdateTime},
         );
     }
 
-    my $SystemTime = $Kernel::OM->Create('Kernel::System::DateTime');
+    my $SystemTime = $TimeObject->SystemTime();
 
     my $Force = $Self->GetOption('force') || 0;
 
     # do not update registration info before the next update (unless is forced)
-    if ( !$Force && $NextUpdateSystemTime && $SystemTime < $NextUpdateSystemTime ) {
+    if ( !$Force && $SystemTime < $NextUpdateSystemTime ) {
         $Self->Print("No need to send the registration update at this moment, skipping...\n");
         $Self->Print("<green>Done.</green>\n");
         return $Self->ExitCodeOk();
     }
 
     # send the registration update
-    my %Result = $Kernel::OM->Get('Kernel::System::Registration')->RegistrationUpdateSend(
-        Debug => $Self->GetOption('debug') || 0,
-    );
+    my %Result = $Kernel::OM->Get('Kernel::System::Registration')->RegistrationUpdateSend();
 
     # if everything is OK return successfully
     if ( $Result{Success} ) {
@@ -112,9 +102,9 @@ sub Run {
     if ( !$NextUpdateTime || $RegistrationData{NextUpdateTime} eq $NextUpdateTime ) {
 
         # calculate next update time set it in two hours
-        $NextUpdateTime = $SystemTime->Clone();
-        $NextUpdateTime->Add( Seconds => 60 * 60 * 2 );
-        $NextUpdateTime = $NextUpdateTime->ToString();
+        $NextUpdateTime = $TimeObject->SystemTime2TimeStamp(
+            SystemTime => $SystemTime + ( 60 * 60 * 2 ),
+        );
 
         # update or set the NextUpdateTime value
         if ( defined $UpdatedRegistrationData{NextUpdateTime} ) {
