@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Console::Command::Maint::Stats::Generate;
@@ -11,7 +11,7 @@ package Kernel::System::Console::Command::Maint::Stats::Generate;
 use strict;
 use warnings;
 
-use parent qw(Kernel::System::Console::BaseCommand);
+use base qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -19,11 +19,10 @@ our @ObjectDependencies = (
     'Kernel::Output::PDF::Statistics',
     'Kernel::System::CSV',
     'Kernel::System::CheckItem',
-    'Kernel::System::DateTime',
     'Kernel::System::Email',
-    'Kernel::System::Main',
     'Kernel::System::PDF',
     'Kernel::System::Stats',
+    'Kernel::System::Time',
     'Kernel::System::User',
 );
 
@@ -72,7 +71,7 @@ sub Configure {
     );
     $Self->AddOption(
         Name        => 'separator',
-        Description => "Define the separator in case of CSV as target format (defaults to ';').",
+        Description => "Defines the separator in case of CSV as target format (defaults to ';').",
         Required    => 0,
         HasValue    => 1,
         ValueRegex  => qr/.*/smx,
@@ -80,7 +79,7 @@ sub Configure {
     $Self->AddOption(
         Name => 'with-header',
         Description =>
-            "Add a heading line consisting of statistics title and creation date in case of Excel or CSV as output format.",
+            "Adds a heading line consisting of statistics title and creation date in case of Excel or CSV as output format.",
         Required   => 0,
         HasValue   => 0,
         ValueRegex => qr/.*/smx,
@@ -88,7 +87,7 @@ sub Configure {
     $Self->AddOption(
         Name => 'timezone',
         Description =>
-            "Target time zone (e.g. Europe/Berlin) for which the file should be generated.",
+            "Target time zone (e.g. +2) for which the file should be generated (only provided, if the system use UTC as system time, the TimeZoneUser feature is active and for dynamic statistics).",
         Required   => 0,
         HasValue   => 1,
         ValueRegex => qr/.*/smx,
@@ -144,7 +143,7 @@ sub PreRun {
 
     # if params have been passed, we build up a body containing the configured params
     # which is then used as default
-    $Self->{Params}   = $Self->GetOption('params');
+    $Self->{Params} = $Self->GetOption('params');
     $Self->{MailBody} = $Self->GetOption('mail-body') || '';
     if ( !$Self->{MailBody} && $Self->{Params} ) {
         $Self->{MailBody} .= "Stats with following options:\n\n";
@@ -168,6 +167,18 @@ sub PreRun {
         die "The target directory '$Self->{TargetDirectory}' does not exist.\n";
     }
 
+    if (
+        $Self->GetOption('timezone')
+        && (
+            $Kernel::OM->Get('Kernel::System::Time')->ServerLocalTimeOffsetSeconds()
+            || !$Kernel::OM->Get('Kernel::Config')->Get('TimeZoneUser')
+        )
+        )
+    {
+        die
+            "You defined a timzone but this is only provided, if the system use UTC as system time and the time zone user support is active.\n";
+    }
+
     # set up used language
     $Self->{Language} = $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage') || 'en';
     if ( $Self->GetOption('language') ) {
@@ -191,7 +202,10 @@ sub Run {
 
     $Self->Print("<yellow>Generating statistic number $Self->{StatNumber}...</yellow>\n");
 
-    my $CurSysDTObject = $Kernel::OM->Create('Kernel::System::DateTime');
+    my ( $s, $m, $h, $D, $M, $Y ) =
+        $Kernel::OM->Get('Kernel::System::Time')->SystemTime2Date(
+        SystemTime => $Kernel::OM->Get('Kernel::System::Time')->SystemTime(),
+        );
 
     my %GetParam;
     my $Stat = $Kernel::OM->Get('Kernel::System::Stats')->StatsGet(
@@ -200,9 +214,9 @@ sub Run {
     );
 
     if ( $Stat->{StatType} eq 'static' ) {
-        $GetParam{Year}  = $CurSysDTObject->Get()->{Year};
-        $GetParam{Month} = $CurSysDTObject->Get()->{Month};
-        $GetParam{Day}   = $CurSysDTObject->Get()->{Day};
+        $GetParam{Year}  = $Y;
+        $GetParam{Month} = $M;
+        $GetParam{Day}   = $D;
 
         # get params from -p
         # only for static files
@@ -257,7 +271,7 @@ sub Run {
             StatID   => $Self->{StatID},
             GetParam => \%GetParam,
             UserID   => 1,
-        )
+        ),
     };
 
     # generate output
@@ -265,7 +279,7 @@ sub Run {
     my $Title          = $TitleArrayRef->[0];
     my $HeadArrayRef   = shift(@StatArray);
     my $CountStatArray = @StatArray;
-    my $Time           = $CurSysDTObject->ToString();
+    my $Time           = sprintf( "%04d-%02d-%02d %02d:%02d:%02d", $Y, $M, $D, $h, $m, $s );
     my @WithHeader;
     if ( $Self->GetOption('with-header') ) {
         @WithHeader = ( "Name: $Title", "Created: $Time" );
@@ -367,20 +381,15 @@ sub Run {
 
     # write output
     if ( $Self->{TargetDirectory} ) {
-
-        my $Success = $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
-            Location => "$Self->{TargetDirectory}/$Attachment{Filename}",
-            Content  => \$Attachment{Content},
-            Mode     => 'binmode',
-        );
-
-        if ($Success) {
+        if ( open my $Filehandle, '>', "$Self->{TargetDirectory}/$Attachment{Filename}" ) {    ## no critic
+            print $Filehandle $Attachment{Content};
+            close $Filehandle;
             $Self->Print("  Writing file <yellow>$Self->{TargetDirectory}/$Attachment{Filename}</yellow>.\n");
             $Self->Print("<green>Done.</green>\n");
             return $Self->ExitCodeOk();
         }
         else {
-            $Self->PrintError("Can't write $Self->{TargetDirectory}/$Attachment{Filename}!");
+            $Self->PrintError("Can't write $Self->{TargetDirectory}/$Attachment{Filename}: $!");
             return $Self->ExitCodeError();
         }
     }
@@ -399,7 +408,7 @@ sub Run {
             next RECIPIENT;
         }
 
-        my $Result = $Kernel::OM->Get('Kernel::System::Email')->Send(
+        $Kernel::OM->Get('Kernel::System::Email')->Send(
             From       => $Self->GetOption('mail-sender'),
             To         => $Recipient,
             Subject    => "[Stats - $CountStatArray Records] $Title; Created: $Time",
@@ -407,13 +416,7 @@ sub Run {
             Charset    => 'utf-8',
             Attachment => [ {%Attachment}, ],
         );
-        if ( $Result->{Success} ) {
-            $Self->Print("<yellow>Email sent to '$Recipient'.</yellow>\n");
-        }
-        else {
-            $Self->Print("<red>Email sending to '$Recipient' has failed.</red>\n");
-        }
-
+        $Self->Print("<yellow>Email sent to '$Recipient'.</yellow>\n");
     }
 
     $Self->Print("<green>Done.</green>\n");
