@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Daemon::DaemonModules::SchedulerGenericAgentTaskManager;
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 use utf8;
 
-use parent qw(Kernel::System::Daemon::BaseDaemon);
+use base qw(Kernel::System::Daemon::BaseDaemon);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -22,19 +22,24 @@ our @ObjectDependencies = (
     'Kernel::System::Daemon::SchedulerDB',
     'Kernel::System::GenericAgent',
     'Kernel::System::Log',
+    'Kernel::System::Time',
 );
 
 =head1 NAME
 
 Kernel::System::Daemon::DaemonModules::SchedulerGenericAgentTaskManager - daemon to manage scheduler generic agent tasks
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 Scheduler generic agent task daemon
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 Create scheduler future task manager object.
 
@@ -112,6 +117,10 @@ sub PostRun {
 
     $Self->{DiscardCount}--;
 
+    if ( $Self->{Debug} ) {
+        print "  $Self->{DaemonName} Discard Count: $Self->{DiscardCount}\n";
+    }
+
     # Unlock long locked tasks.
     $Self->{SchedulerDBObject}->RecurrentTaskUnlockExpired(
         Type => 'GenericAgent',
@@ -120,10 +129,6 @@ sub PostRun {
     # Remove obsolete tasks before destroy.
     if ( $Self->{DiscardCount} == 0 ) {
         $Self->{SchedulerDBObject}->GenericAgentTaskCleanup();
-
-        if ( $Self->{Debug} ) {
-            print "  $Self->{DaemonName} will be stopped and set for restart!\n";
-        }
     }
 
     return if $Self->{DiscardCount} <= 0;
@@ -144,12 +149,14 @@ sub DESTROY {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
