@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Encode;
@@ -51,6 +51,9 @@ sub new {
     # 0=off; 1=on;
     $Self->{Debug} = 0;
 
+    # use "locale" as an arg to encode/decode
+    @ARGV = map { decode( locale => $_, 1 ) } @ARGV;
+
     # check if the encodeobject is used from the command line
     # if so, we need to decode @ARGV
     if ( !is_interactive() ) {
@@ -60,10 +63,6 @@ sub new {
     }
     else {
 
-        # use "locale" as an arg to encode/decode
-        if ( is_interactive(*STDIN) ) {
-            @ARGV = map { decode( locale => $_, 1 ) } @ARGV;
-        }
         if ( is_interactive(*STDOUT) ) {
             binmode STDOUT, ":encoding(console_out)";
         }
@@ -132,19 +131,14 @@ sub Convert {
         if ( $Param{Check} && !eval { Encode::is_utf8( $Param{Text}, 1 ) } ) {
             Encode::_utf8_off( $Param{Text} );
 
-            # We should not output error messages about invalid strings by default, as this happens regularly
-            #   with certain input data from SPAM mails and such.
-            if ( $Self->{Debug} ) {
-
-                # truncate text for error messages
-                my $TruncatedText = $Param{Text};
-                if ( length($TruncatedText) > 65 ) {
-                    $TruncatedText = substr( $TruncatedText, 0, 65 ) . '[...]';
-                }
-
-                print STDERR "No valid '$Param{To}' string: '$TruncatedText'!\n";
+            # truncate text for error messages
+            my $TruncatedText = $Param{Text};
+            if ( length($TruncatedText) > 65 ) {
+                $TruncatedText = substr( $TruncatedText, 0, 65 ) . '[...]';
             }
 
+            print STDERR "No valid '$Param{To}' string: '$TruncatedText'!\n";
+
             # strip invalid chars / 0 = will put a substitution character in
             # place of a malformed character
             eval { Encode::from_to( $Param{Text}, $Param{From}, $Param{To}, 0 ) };
@@ -422,46 +416,16 @@ sub FindAsciiSupersetEncoding {
     return 'ASCII';
 }
 
-#
-# DEPRECATED METHODS
-#
-
-# COMPAT: to OTRS 3.0
-sub CharsetInternal {
-    my $Self = shift;
-
-    return 'utf-8';
-}
-
-# COMPAT: to OTRS 1.x and 2.x (can be removed later)
-sub EncodeInternalUsed {
-    my $Self = shift;
-
-    return $Self->CharsetInternal(@_);
-}
-
-sub Encode {
-    my $Self = shift;
-
-    return $Self->EncodeInput(@_);
-}
-
-sub Decode {
-    my $Self = shift;
-
-    return $Self->Convert2CharsetInternal(@_);
-}
-
 1;
 
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
