@@ -1,6 +1,5 @@
 # --
-# Kernel/System/ProcessManagement/TransitionAction/TicketServiceSet.pm - A Module to set the ticket service
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,10 +10,17 @@ package Kernel::System::ProcessManagement::TransitionAction::TicketServiceSet;
 
 use strict;
 use warnings;
+use utf8;
+
 use Kernel::System::VariableCheck qw(:all);
 
-use utf8;
-use Kernel::System::Service;
+use base qw(Kernel::System::ProcessManagement::TransitionAction::Base);
+
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::Service',
+    'Kernel::System::Ticket',
+);
 
 =head1 NAME
 
@@ -32,57 +38,11 @@ All TicketServiceSet functions.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::Ticket;
-    use Kernel::System::ProcessManagement::TransitionAction::TicketServiceSet;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $TicketObject = Kernel::System::Ticket->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        EncodeObject       => $EncodeObject,
-    );
-    my $TicketServiceSetActionObject= Kernel::System::ProcessManagement::TransitionAction::TicketServiceSet->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        EncodeObject       => $EncodeObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        TicketObject       => $TicketObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $TicketServiceSetObject = $Kernel::OM->Get('Kernel::System::ProcessManagement::TransitionAction::TicketServiceSet');
 
 =cut
 
@@ -93,23 +53,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (
-        qw(ConfigObject LogObject EncodeObject DBObject MainObject TimeObject TicketObject)
-        )
-    {
-        die "Got no $Needed!" if !$Param{$Needed};
-
-        $Self->{$Needed} = $Param{$Needed};
-    }
-
-    $Self->{ServiceObject} = Kernel::System::Service->new(
-        %Param,
-        DBObject   => $Self->{DBObject},
-        MainObject => $Self->{MainObject},
-        TimeObject => $Self->{TimeObject},
-    );
-
     return $Self;
 }
 
@@ -120,10 +63,10 @@ sub new {
     my $TicketServiceSetResult = $TicketServiceSetActionObject->Run(
         UserID                   => 123,
         Ticket                   => \%Ticket,   # required
-        ProcessEntityID          => 'P123',     # optional
-        ActivityEntityID         => 'A123',     # optional
-        TransitionEntityID       => 'T123',     # optional
-        TransitionActionEntityID => 'TA123',    # optional
+        ProcessEntityID          => 'P123',
+        ActivityEntityID         => 'A123',
+        TransitionEntityID       => 'T123',
+        TransitionActionEntityID => 'TA123',
         Config                   => {
             Service => 'MyService::Subservice',
             # or
@@ -142,67 +85,26 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    for my $Needed (qw(UserID Ticket Config)) {
-        if ( !defined $Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!",
-            );
-            return;
-        }
-    }
-
     # define a common message to output in case of any error
-    my $CommonMessage;
-    if ( $Param{ProcessEntityID} ) {
-        $CommonMessage .= "Process: $Param{ProcessEntityID}";
-    }
-    if ( $Param{ActivityEntityID} ) {
-        $CommonMessage .= " Activity: $Param{ActivityEntityID}";
-    }
-    if ( $Param{TransitionEntityID} ) {
-        $CommonMessage .= " Transition: $Param{TransitionEntityID}";
-    }
-    if ( $Param{TransitionActionEntityID} ) {
-        $CommonMessage .= " TransitionAction: $Param{TransitionActionEntityID}";
-    }
-    if ($CommonMessage) {
+    my $CommonMessage = "Process: $Param{ProcessEntityID} Activity: $Param{ActivityEntityID}"
+        . " Transition: $Param{TransitionEntityID}"
+        . " TransitionAction: $Param{TransitionActionEntityID} - ";
 
-        # add a separator
-        $CommonMessage .= " - ";
-    }
-    else {
-
-        # otherwise at least define it to prevent errors
-        $CommonMessage = '';
-    }
-
-    # Check if we have Ticket to deal with
-    if ( !IsHashRefWithData( $Param{Ticket} ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => $CommonMessage . "Ticket has no values!",
-        );
-        return;
-    }
-
-    # Check if we have a ConfigHash
-    if ( !IsHashRefWithData( $Param{Config} ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => $CommonMessage . "Config has no values!",
-        );
-        return;
-    }
+    # check for missing or wrong params
+    my $Success = $Self->_CheckParams(
+        %Param,
+        CommonMessage => $CommonMessage,
+    );
+    return if !$Success;
 
     # override UserID if specified as a parameter in the TA config
-    if ( IsNumber( $Param{Config}->{UserID} ) ) {
-        $Param{UserID} = $Param{Config}->{UserID};
-        delete $Param{Config}->{UserID};
-    }
+    $Param{UserID} = $Self->_OverrideUserID(%Param);
+
+    # use ticket attributes if needed
+    $Self->_ReplaceTicketAttributes(%Param);
 
     if ( !$Param{Config}->{ServiceID} && !$Param{Config}->{Service} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage . "No Service or ServiceID configured!",
         );
@@ -210,14 +112,14 @@ sub Run {
     }
 
     if ( !$Param{Ticket}->{CustomerUserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage . "To set a service the ticket requires a customer!",
         );
         return;
     }
 
-    my $Success;
+    $Success = 0;
 
     # If Ticket's ServiceID is already the same as the Value we
     # should set it to, we got nothing to do and return success
@@ -249,7 +151,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'ServiceID '
@@ -261,14 +163,14 @@ sub Run {
         }
 
         # set ticket service
-        $Success = $Self->{TicketObject}->TicketServiceSet(
+        $Success = $Kernel::OM->Get('Kernel::System::Ticket')->TicketServiceSet(
             TicketID  => $Param{Ticket}->{TicketID},
             ServiceID => $Param{Config}->{ServiceID},
             UserID    => $Param{UserID},
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Ticket ServiceID '
@@ -303,12 +205,12 @@ sub Run {
         )
     {
 
-        my $ServiceID = $Self->{ServiceObject}->ServiceLookup(
+        my $ServiceID = $Kernel::OM->Get('Kernel::System::Service')->ServiceLookup(
             Name => $Param{Config}->{Service},
         );
 
         if ( !$ServiceID ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Service '
@@ -325,7 +227,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Service '
@@ -337,14 +239,14 @@ sub Run {
         }
 
         # set ticket service
-        $Success = $Self->{TicketObject}->TicketServiceSet(
+        $Success = $Kernel::OM->Get('Kernel::System::Ticket')->TicketServiceSet(
             TicketID => $Param{Ticket}->{TicketID},
             Service  => $Param{Config}->{Service},
             UserID   => $Param{UserID},
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Ticket Service '
@@ -355,7 +257,7 @@ sub Run {
         }
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage
                 . "Couldn't update Ticket Service - can't find valid Service parameter!",
@@ -378,13 +280,14 @@ checks if a service is assigned to a customer user
     Returns:
 
     $Success = 1;       # or undef
+
 =cut
 
 sub _CheckService {
     my ( $Self, %Param ) = @_;
 
     # get a list of assigned services to the customer user
-    my %Services = $Self->{ServiceObject}->CustomerUserServiceMemberList(
+    my %Services = $Kernel::OM->Get('Kernel::System::Service')->CustomerUserServiceMemberList(
         CustomerUserLogin => $Param{UserLogin},
         Result            => 'HASH',
         DefaultServices   => 1,
@@ -399,6 +302,7 @@ sub _CheckService {
     # otherwise return success
     return 1;
 }
+
 1;
 
 =back
