@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::SupportDataCollector::Plugin::Database::mysql::MaxAllowedPacket;
@@ -13,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::DB',
 );
 
 sub GetDisplayPath {
-    return 'Database';
+    return Translatable('Database');
 }
 
 sub Run {
@@ -40,15 +42,15 @@ sub Run {
             )
         {
             $Self->AddResultProblem(
-                Label => 'Maximum Query Size',
+                Label => Translatable('Maximum Query Size'),
                 Value => $Row[1] / 1024 / 1024 . ' MB',
                 Message =>
-                    "The setting 'max_allowed_packet' must be higher than 20 MB.",
+                    Translatable("The setting 'max_allowed_packet' must be higher than 20 MB."),
             );
         }
         else {
             $Self->AddResultOk(
-                Label => 'Maximum Query Size',
+                Label => Translatable('Maximum Query Size'),
                 Value => $Row[1] / 1024 / 1024 . ' MB',
             );
         }
@@ -57,16 +59,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<https://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
-
-=cut
-
 1;
