@@ -1,5 +1,4 @@
 # --
-# Kernel/System/SupportDataCollector/Plugin/OTRS/ConfigSettings.pm - system data collector plugin
 # Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -14,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
 );
 
 sub GetDisplayPath {
-    return 'OTRS/Config Settings';
+    return Translatable('OTRS') . '/' . Translatable('Config Settings');
 }
 
 sub Run {
@@ -60,7 +61,7 @@ sub Run {
                 Identifier => $Setting,
                 Label      => $Setting,
                 Value      => $ConfigValue,
-                Message    => 'Could not determine value.',
+                Message    => Translatable('Could not determine value.'),
             );
         }
     }
@@ -68,16 +69,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
