@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,8 @@ use strict;
 use warnings;
 
 use Kernel::System::Email;
+use Kernel::System::VariableCheck qw(IsArrayRefWithData);
+use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -165,14 +167,14 @@ sub Run {
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
         if ( !$DBCanConnect ) {
             $LayoutObject->CustomerFatalError(
-                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+                Comment => Translatable('Please contact the administrator.'),
             );
             return;
         }
         if ( $ParamObject->Error() ) {
             $LayoutObject->CustomerFatalError(
                 Message => $ParamObject->Error(),
-                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+                Comment => Translatable('Please contact the administrator.'),
             );
             return;
         }
@@ -271,8 +273,7 @@ sub Run {
                         What => 'Message',
                         )
                         || $AuthObject->GetLastErrorMessage()
-                        || $LayoutObject->{LanguageObject}
-                        ->Translate('Login failed! Your user name or password was entered incorrectly.'),
+                        || Translatable('Login failed! Your user name or password was entered incorrectly.'),
                     User        => $PostUser,
                     LoginFailed => 1,
                     %Param,
@@ -313,11 +314,10 @@ sub Run {
             # show need user data error message
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
-                    Title => 'Panic!',
-                    Message =>
-                        $LayoutObject->{LanguageObject}->Translate(
-                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact your administrator.'
-                        ),
+                    Title   => 'Panic!',
+                    Message => Translatable(
+                        'Authentication succeeded, but no customer record is found in the customer backend. Please contact the administrator.'
+                    ),
                     %Param,
                 ),
             );
@@ -375,7 +375,7 @@ sub Run {
             SystemTime => ( $TimeObject->SystemTime() + 20 ),
         );
 
-        # add a asychronous executor scheduler task to count the concurrent user
+        # add a asynchronous executor scheduler task to count the concurrent user
         $Kernel::OM->Get('Kernel::System::Scheduler')->TaskAdd(
             ExecutionTime            => $ExecutionTime,
             Type                     => 'AsynchronousExecutor',
@@ -474,7 +474,7 @@ sub Run {
             # show login screen
             print $LayoutObject->CustomerLogin(
                 Title   => 'Logout',
-                Message => $LayoutObject->{LanguageObject}->Translate('Session invalid. Please log in again.'),
+                Message => Translatable('Session invalid. Please log in again.'),
                 %Param,
             );
             return;
@@ -509,7 +509,7 @@ sub Run {
         # remove session id
         if ( !$SessionObject->RemoveSessionID( SessionID => $Param{SessionID} ) ) {
             $LayoutObject->CustomerFatalError(
-                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator')
+                Comment => Translatable('Please contact the administrator.')
             );
             return;
         }
@@ -523,10 +523,7 @@ sub Run {
         }
 
         # show logout screen
-        my $LogoutMessage = $LayoutObject->{LanguageObject}->Translate(
-            'Logout successful. Thank you for using %s!',
-            $ConfigObject->Get("ProductName"),
-        );
+        my $LogoutMessage = $LayoutObject->{LanguageObject}->Translate('Logout successful.');
 
         $LayoutObject->Print(
             Output => \$LayoutObject->CustomerLogin(
@@ -552,7 +549,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
+                    Message => Translatable('Feature not active!'),
                 ),
             );
             return;
@@ -586,7 +583,7 @@ sub Run {
 
         # verify customer user is valid when requesting password reset
         my @ValidIDs = $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet();
-        my $UserIsValid = grep { $UserData{ValidID} == $_ } @ValidIDs;
+        my $UserIsValid = grep { $UserData{ValidID} && $UserData{ValidID} == $_ } @ValidIDs;
         if ( !$UserData{UserID} || !$UserIsValid ) {
 
             # Security: pretend that password reset instructions were actually sent to
@@ -594,9 +591,8 @@ sub Run {
             #   just trying and checking the result message.
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
-                    Title   => 'Login',
-                    Message => $LayoutObject->{LanguageObject}
-                        ->Translate('Sent password reset instructions. Please check your email.'),
+                    Title       => 'Login',
+                    Message     => Translatable('Sent password reset instructions. Please check your email.'),
                     MessageType => 'Success',
                 ),
             );
@@ -631,15 +627,14 @@ sub Run {
             );
             if ( !$Sent ) {
                 $LayoutObject->FatalError(
-                    Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+                    Comment => Translatable('Please contact the administrator.'),
                 );
                 return;
             }
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => $LayoutObject->{LanguageObject}
-                        ->Translate('Sent password reset instructions. Please check your email.'),
+                    Message => Translatable('Sent password reset instructions. Please check your email.'),
                     %Param,
                     MessageType => 'Success',
                 ),
@@ -658,7 +653,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => 'Invalid Token!',
+                    Message => Translatable('Invalid Token!'),
                     %Param,
                 ),
             );
@@ -677,11 +672,9 @@ sub Run {
         if ( !$Success ) {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
-                    Title => 'Login',
-                    Message =>
-                        $LayoutObject->{LanguageObject}
-                        ->Translate('Reset password unsuccessful. Please contact your administrator'),
-                    User => $User,
+                    Title   => 'Login',
+                    Message => Translatable('Reset password unsuccessful. Please contact the administrator.'),
+                    User    => $User,
                 ),
             );
             return;
@@ -704,7 +697,7 @@ sub Run {
         );
         if ( !$Sent ) {
             $LayoutObject->CustomerFatalError(
-                Comment => 'Please contact your administrator'
+                Comment => Translatable('Please contact the administrator.')
             );
             return;
         }
@@ -736,7 +729,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Login',
-                    Message => $LayoutObject->{LanguageObject}->Translate('Feature not active!'),
+                    Message => Translatable('Feature not active!'),
                 ),
             );
             return;
@@ -769,8 +762,7 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        $LayoutObject->{LanguageObject}
-                        ->Translate('This e-mail address already exists. Please log in or reset your password.'),
+                        Translatable('This e-mail address already exists. Please log in or reset your password.'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -827,8 +819,7 @@ sub Run {
                 Output => \$LayoutObject->CustomerLogin(
                     Title => 'Login',
                     Message =>
-                        $LayoutObject->{LanguageObject}
-                        ->Translate('This email address is not allowed to register. Please contact support staff.'),
+                        Translatable('This email address is not allowed to register. Please contact support staff.'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -845,7 +836,7 @@ sub Run {
         );
         my $Add = $UserObject->CustomerUserAdd(
             %GetParams,
-            Comment => "Added via Customer Panel ($Now)",
+            Comment => $LayoutObject->{LanguageObject}->Translate( 'Added via Customer Panel (%s)', $Now ),
             ValidID => 1,
             UserID  => $ConfigObject->Get('CustomerPanelUserID'),
         );
@@ -854,7 +845,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title         => 'Login',
-                    Message       => 'Customer user can\'t be added!',
+                    Message       => Translatable('Customer user can\'t be added!'),
                     UserTitle     => $GetParams{UserTitle},
                     UserFirstname => $GetParams{UserFirstname},
                     UserLastname  => $GetParams{UserLastname},
@@ -888,7 +879,7 @@ sub Run {
                 Title => 'Error'
             );
             $Output .= $LayoutObject->CustomerWarning(
-                Comment => 'Can\'t send account info!'
+                Comment => Translatable('Can\'t send account info!')
             );
             $Output .= $LayoutObject->CustomerFooter();
             $LayoutObject->Print( Output => \$Output );
@@ -1047,7 +1038,7 @@ sub Run {
             $LayoutObject->Print(
                 Output => \$LayoutObject->CustomerLogin(
                     Title   => 'Panic!',
-                    Message => $LayoutObject->{LanguageObject}->Translate('Panic! Invalid Session!!!'),
+                    Message => Translatable('Panic! Invalid Session!!!'),
                     %Param,
                 ),
             );
@@ -1066,58 +1057,77 @@ sub Run {
                     "Module Kernel::Modules::$Param{Action} not registered in Kernel/Config.pm!",
             );
             $LayoutObject->CustomerFatalError(
-                Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+                Comment => Translatable('Please contact the administrator.'),
             );
             return;
         }
 
-        # module permisson check
+        # module permission check for action
         if ( !$ModuleReg->{GroupRo} && !$ModuleReg->{Group} ) {
             $Param{AccessRo} = 1;
             $Param{AccessRw} = 1;
         }
         else {
-            PERMISSION:
-            for my $Permission (qw(GroupRo Group)) {
-                my $AccessOk = 0;
-                my $Group    = $ModuleReg->{$Permission};
-                my $Key      = "UserIs$Permission";
-                next PERMISSION if !$Group;
-                if ( ref $Group eq 'ARRAY' ) {
-                    GROUP:
-                    for ( @{$Group} ) {
-                        next GROUP if !$_;
-                        next GROUP if !$UserData{ $Key . "[$_]" };
-                        next GROUP if $UserData{ $Key . "[$_]" } ne 'Yes';
-                        $AccessOk = 1;
-                        last GROUP;
-                    }
-                }
-                else {
-                    if ( $UserData{ $Key . "[$Group]" } && $UserData{ $Key . "[$Group]" } eq 'Yes' )
-                    {
-                        $AccessOk = 1;
-                    }
-                }
-                if ( $Permission eq 'Group' && $AccessOk ) {
-                    $Param{AccessRo} = 1;
-                    $Param{AccessRw} = 1;
-                }
-                elsif ( $Permission eq 'GroupRo' && $AccessOk ) {
-                    $Param{AccessRo} = 1;
-                }
-            }
+
+            ( $Param{AccessRo}, $Param{AccessRw} ) = $Self->_CheckModulePermission(
+                ModuleReg => $ModuleReg,
+                %UserData,
+            );
+
             if ( !$Param{AccessRo} ) {
 
                 # new layout object
                 my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
                 $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
-                    Message  => 'No Permission to use this frontend module!'
+                    Message  => 'No Permission to use this frontend action module!'
+                );
+                $LayoutObject->CustomerFatalError(
+                    Comment => Translatable('Please contact the administrator.'),
                 );
-                $LayoutObject->CustomerFatalError( Comment => 'Please contact your administrator' );
                 return;
             }
+
+        }
+
+        # module permission check for submenu item
+        if ( IsArrayRefWithData( $ModuleReg->{NavBar} ) ) {
+            LINKCHECK:
+            for my $ModuleReg ( @{ $ModuleReg->{NavBar} } ) {
+                next LINKCHECK if $Param{RequestedURL} !~ m/Subaction/i;
+                if ( $ModuleReg->{Link} =~ m/Subaction=/i && $ModuleReg->{Link} !~ m/$Param{Subaction}/i ) {
+                    next LINKCHECK;
+                }
+                $Param{AccessRo} = 0;
+                $Param{AccessRw} = 0;
+
+                # module permission check for submenu item
+                if ( !$ModuleReg->{GroupRo} && !$ModuleReg->{Group} ) {
+                    $Param{AccessRo} = 1;
+                    $Param{AccessRw} = 1;
+                }
+                else {
+
+                    ( $Param{AccessRo}, $Param{AccessRw} ) = $Self->_CheckModulePermission(
+                        ModuleReg => $ModuleReg,
+                        %UserData,
+                    );
+
+                    if ( !$Param{AccessRo} ) {
+
+                        # new layout object
+                        my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
+                            Priority => 'error',
+                            Message  => 'No Permission to use this frontend subaction module!'
+                        );
+                        $LayoutObject->CustomerFatalError(
+                            Comment => Translatable('Please contact the administrator.')
+                        );
+                        return;
+                    }
+                }
+            }
         }
 
         # create new LayoutObject with new '%Param' and '%UserData'
@@ -1133,7 +1143,11 @@ sub Run {
         my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
         # update last request time
-        if ( !$ParamObject->IsAJAXRequest() ) {
+        if (
+            !$ParamObject->IsAJAXRequest()
+            || $Param{Action} eq 'CustomerVideoChat'
+            )
+        {
             $SessionObject->UpdateSessionID(
                 SessionID => $Param{SessionID},
                 Key       => 'UserLastRequest',
@@ -1192,6 +1206,7 @@ sub Run {
             %Param,
             %UserData,
             ModuleReg => $ModuleReg,
+            Debug     => $Self->{Debug},
         );
 
         # debug info
@@ -1248,11 +1263,69 @@ sub Run {
     );
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
     $LayoutObject->CustomerFatalError(
-        Comment => $LayoutObject->{LanguageObject}->Translate('Please contact your administrator'),
+        Comment => Translatable('Please contact the administrator.'),
     );
     return;
 }
 
+=begin Internal:
+
+=item _CheckModulePermission()
+
+module permission check
+
+    ($AccessRo, $AccessRw = $AutoResponseObject->_CheckModulePermission(
+        ModuleReg => $ModuleReg,
+        %UserData,
+    );
+
+=cut
+
+sub _CheckModulePermission {
+    my ( $Self, %Param ) = @_;
+
+    my $AccessRo = 0;
+    my $AccessRw = 0;
+
+    PERMISSION:
+    for my $Permission (qw(GroupRo Group)) {
+        my $AccessOk = 0;
+        my $Group    = $Param{ModuleReg}->{$Permission};
+
+        my $Key = "UserIs$Permission";
+        next PERMISSION if !$Group;
+        if ( IsArrayRefWithData($Group) ) {
+            GROUP:
+            for my $Item ( @{$Group} ) {
+                next GROUP if !$Item;
+                next GROUP if !$Param{ $Key . "[$Item]" };
+                next GROUP if $Param{ $Key . "[$Item]" } ne 'Yes';
+                $AccessOk = 1;
+                last GROUP;
+            }
+        }
+        else {
+            if ( $Param{ $Key . "[$Group]" } && $Param{ $Key . "[$Group]" } eq 'Yes' )
+            {
+                $AccessOk = 1;
+            }
+        }
+        if ( $Permission eq 'Group' && $AccessOk ) {
+            $AccessRo = 1;
+            $AccessRw = 1;
+        }
+        elsif ( $Permission eq 'GroupRo' && $AccessOk ) {
+            $AccessRo = 1;
+        }
+    }
+
+    return ( $AccessRo, $AccessRw );
+}
+
+=end Internal:
+
+=cut
+
 sub DESTROY {
     my $Self = shift;
 
