@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -30,17 +30,6 @@ use lib dirname($RealBin) . '/Custom';
 use Kernel::System::Environment;
 use Kernel::System::VariableCheck qw( :all );
 
-# on Windows, we only have ANSI support if Win32::Console::ANSI is present
-# turn off colors if it is not available
-BEGIN {
-    if ( $^O eq 'MSWin32' ) {
-        ## no critic
-        eval 'use Win32::Console::ANSI';
-        ## use critic
-        $ENV{nocolors} = 1 if $@;
-    }
-}
-
 use Linux::Distribution;
 use ExtUtils::MakeMaker;
 use File::Path;
@@ -65,6 +54,10 @@ our %InstTypeToCMD = (
         CMD       => 'apt-get install -y %s',
         UseModule => 0,
     },
+    emerge => {
+        CMD       => 'emerge %s',
+        UseModule => 0,
+    },
     ppm => {
         CMD       => 'ppm install %s',
         UseModule => 0,
@@ -89,6 +82,11 @@ our %DistToInstType = (
     debian => 'aptget',
     ubuntu => 'aptget',
 
+    # emerge
+    # for reasons unknown, some environments return "gentoo" (incl. the quotes)
+    '"gentoo"' => 'emerge',
+    gentoo     => 'emerge',
+
     # yum
     centos => 'yum',
     fedora => 'yum',
@@ -97,19 +95,10 @@ our %DistToInstType = (
 
     # zypper
     suse => 'zypper',
-
-    # ppm
-    win32as => 'ppm',
 );
 
 our $OSDist = Linux::Distribution::distribution_name() || '';
 
-# set win32as if active state perl is installed on windows.
-# for windows installations without active state perl we use the default.
-if ( _CheckActiveStatePerl() ) {
-    $OSDist = 'win32as';
-}
-
 my $AllModules;
 my $PackageList;
 my $Help;
@@ -122,7 +111,7 @@ GetOptions(
 # check needed params
 if ($Help) {
     print "otrs.CheckModules.pl - OTRS CheckModules\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2016 OTRS AG, http://otrs.com/\n";
     print "usage: otrs.CheckModules.pl [-list|all] \n";
     print "
    otrs.CheckModules.pl
@@ -143,17 +132,25 @@ if ( $ENV{nocolors} || $Options =~ m{\A nocolors}msxi ) {
     $NoColors = 1;
 }
 
-my $ExitCode = 0;    # success
-
 # config
 my @NeededModules = (
+    {
+        Module    => 'Apache::DBI',
+        Required  => 0,
+        Comment   => 'Improves Performance on Apache webservers with mod_perl enabled.',
+        InstTypes => {
+            aptget => 'libapache-dbi-perl',
+            emerge => 'dev-perl/Apache-DBI',
+            zypper => 'perl-Apache-DBI',
+        },
+    },
     {
         Module    => 'Apache2::Reload',
         Required  => 0,
         Comment   => 'Avoids web server restarts on mod_perl.',
         InstTypes => {
             aptget => 'libapache2-mod-perl2',
-            ppm    => 'mod_perl-2.0',
+            emerge => 'dev-perl/Apache-Reload',
             zypper => 'apache2-mod_perl',
         },
     },
@@ -162,6 +159,7 @@ my @NeededModules = (
         Required  => 1,
         Comment   => 'Required for compressed file generation (in perlcore).',
         InstTypes => {
+            emerge => 'perl-core/Archive-Tar',
             zypper => 'perl-Archive-Tar',
         },
     },
@@ -171,6 +169,7 @@ my @NeededModules = (
         Comment   => 'Required for compressed file generation.',
         InstTypes => {
             aptget => 'libarchive-zip-perl',
+            emerge => 'dev-perl/Archive-Zip',
             zypper => 'Archive-Zip',
             zypper => 'perl-Archive-Zip',
         },
@@ -181,7 +180,7 @@ my @NeededModules = (
         Comment   => 'For strong password hashing.',
         InstTypes => {
             aptget => 'libcrypt-eksblowfish-perl',
-            ppm    => 'Crypt-Eksblowfish',
+            emerge => 'dev-perl/Crypt-Eksblowfish',
             zypper => 'perl-Crypt-Eksblowfish',
         },
     },
@@ -191,7 +190,7 @@ my @NeededModules = (
         Comment   => 'Required for Generic Interface REST transport and SOAP SSL connections.',
         InstTypes => {
             aptget => 'libcrypt-ssleay-perl',
-            ppm    => 'Crypt-SSLeay',
+            emerge => 'dev-perl/Crypt-SSLeay',
             zypper => 'perl-Crypt-SSLeay',
         },
     },
@@ -200,7 +199,7 @@ my @NeededModules = (
         Required  => 1,
         InstTypes => {
             aptget => 'libtimedate-perl',
-            ppm    => 'TimeDate',
+            emerge => 'dev-perl/TimeDate',
             zypper => 'perl-TimeDate',
         },
     },
@@ -209,7 +208,7 @@ my @NeededModules = (
         Required  => 1,
         InstTypes => {
             aptget => 'libdbi-perl',
-            ppm    => 'DBI',
+            emerge => 'dev-perl/DBI',
             zypper => 'perl-DBI'
         },
     },
@@ -219,7 +218,7 @@ my @NeededModules = (
         Comment   => 'Required to connect to a MySQL database.',
         InstTypes => {
             aptget => 'libdbd-mysql-perl',
-            ppm    => 'DBD-mysql',
+            emerge => 'dev-perl/DBD-mysql',
             zypper => 'perl-DBD-mysql'
         },
     },
@@ -236,7 +235,7 @@ my @NeededModules = (
         Comment   => 'Required to connect to a MS-SQL database.',
         InstTypes => {
             aptget => 'libdbd-odbc-perl',
-            ppm    => 'DBD-ODBC',
+            emerge => undef,
             yum    => undef,
             zypper => undef,
         },
@@ -247,7 +246,7 @@ my @NeededModules = (
         Comment   => 'Required to connect to a Oracle database.',
         InstTypes => {
             aptget => undef,
-            ppm    => 'DBD-Oracle',
+            emerge => undef,
             yum    => undef,
             zypper => undef,
         },
@@ -258,7 +257,7 @@ my @NeededModules = (
         Comment   => 'Required to connect to a PostgreSQL database.',
         InstTypes => {
             aptget => 'libdbd-pg-perl',
-            ppm    => 'DBD-Pg',
+            emerge => 'dev-perl/DBD-Pg',
             zypper => 'perl-DBD-Pg',
         },
     },
@@ -278,48 +277,17 @@ my @NeededModules = (
         Comment   => 'Required to handle mails with several Chinese character sets.',
         InstTypes => {
             aptget => 'libencode-hanextra-perl',
+            emerge => 'dev-perl/Encode-HanExtra',
             zypper => 'perl-Encode-HanExtra',
         },
     },
-    {
-        Module    => 'GD',
-        Required  => 0,
-        Comment   => 'Required for stats.',
-        InstTypes => {
-            aptget => 'libgd-gd2-perl',
-            ppm    => 'GD',
-            zypper => 'perl-GD',
-        },
-        Depends => [
-            {
-                Module    => 'GD::Text',
-                Required  => 0,
-                Comment   => 'Required for stats.',
-                InstTypes => {
-                    aptget => 'libgd-text-perl',
-                    ppm    => 'GDTextUtil',
-                    zypper => 'perl-GDTextUtil',
-                },
-            },
-            {
-                Module    => 'GD::Graph',
-                Required  => 0,
-                Comment   => 'Required for stats.',
-                InstTypes => {
-                    aptget => 'libgd-graph-perl',
-                    ppm    => 'GDGraph',
-                    zypper => 'perl-GDGraph',
-                },
-            },
-        ],
-    },
     {
         Module    => 'IO::Socket::SSL',
         Required  => 0,
         Comment   => 'Required for SSL connections to web and mail servers.',
         InstTypes => {
             aptget => 'libio-socket-ssl-perl',
-            ppm    => 'IO-Socket-SSL',
+            emerge => 'dev-perl/IO-Socket-SSL',
             zypper => 'perl-IO-Socket-SSL',
         },
     },
@@ -329,7 +297,7 @@ my @NeededModules = (
         Comment   => 'Recommended for faster AJAX/JavaScript handling.',
         InstTypes => {
             aptget => 'libjson-xs-perl',
-            ppm    => 'JSON-XS',
+            emerge => 'dev-perl/JSON-XS',
             zypper => 'perl-JSON-XS',
         },
     },
@@ -340,7 +308,7 @@ my @NeededModules = (
             "Do a 'force install Scalar::Util' via cpan shell to fix this problem. Please make sure to have an c compiler and make installed before.",
         InstTypes => {
             aptget => 'libscalar-list-utils-perl',
-            ppm    => 'List-UtilsBy-XS',
+            emerge => 'perl-core/Scalar-List-Utils',
             zypper => 'perl-Scalar-List-Utils',
         },
     },
@@ -349,7 +317,7 @@ my @NeededModules = (
         Required  => 1,
         InstTypes => {
             aptget => 'libwww-perl',
-            ppm    => 'libwww-perl',
+            emerge => 'dev-perl/libwww-perl',
             zypper => 'perl-libwww-perl',
         },
     },
@@ -360,7 +328,7 @@ my @NeededModules = (
         Required  => 0,
         InstTypes => {
             aptget => 'libmail-imapclient-perl',
-            ppm    => 'Mail-IMAPClient',
+            emerge => 'dev-perl/Mail-IMAPClient',
             zypper => 'perl-Mail-IMAPClient',
         },
         Depends => [
@@ -370,30 +338,10 @@ my @NeededModules = (
                 Comment   => 'Required for IMAP TLS connections.',
                 InstTypes => {
                     aptget => 'libio-socket-ssl-perl',
-                    ppm    => 'IO-Socket-SSL',
+                    emerge => 'dev-perl/IO-Socket-SSL',
                     zypper => 'perl-IO-Socket-SSL',
                 },
             },
-            {
-                Module    => 'Authen::SASL',
-                Required  => 0,
-                Comment   => 'Required for MD5 authentication mechanisms in IMAP connections.',
-                InstTypes => {
-                    aptget => 'libauthen-sasl-perl',
-                    emerge => 'dev-perl/Authen-SASL',
-                    zypper => 'perl-Authen-SASL',
-                },
-            },
-            {
-                Module    => 'Authen::NTLM',
-                Required  => 0,
-                Comment   => 'Required for NTLM authentication mechanism in IMAP connections.',
-                InstTypes => {
-                    aptget => 'libauthen-ntlm-perl',
-                    emerge => 'dev-perl/Authen-NTLM',
-                    zypper => 'perl-Authen-NTLM',
-                },
-            },
         ],
     },
     {
@@ -402,6 +350,7 @@ my @NeededModules = (
         Comment   => 'Improves Performance on Apache webservers dramatically.',
         InstTypes => {
             aptget => 'libapache2-mod-perl2',
+            emerge => 'www-apache/mod_perl',
             zypper => 'apache2-mod_perl',
         },
     },
@@ -417,7 +366,7 @@ my @NeededModules = (
         ],
         InstTypes => {
             aptget => 'libnet-dns-perl',
-            ppm    => 'Net-DNS',
+            emerge => 'dev-perl/Net-DNS',
             zypper => 'perl-Net-DNS',
         },
     },
@@ -427,50 +376,17 @@ my @NeededModules = (
         Comment   => 'Required for directory authentication.',
         InstTypes => {
             aptget => 'libnet-ldap-perl',
-            ppm    => 'Net-LDAP',
+            emerge => 'dev-perl/perl-ldap',
             zypper => 'perl-ldap',
         },
     },
-    {
-        Module       => 'PDF::API2',
-        Version      => '0.57',
-        Required     => 0,
-        Comment      => 'Required for PDF output.',
-        NotSupported => [
-            {
-                Version => '0.71.001',
-                Comment =>
-                    'This version is broken and not useable! Please upgrade to a higher version.',
-            },
-            {
-                Version => '0.72.001',
-                Comment =>
-                    'This version is broken and not useable! Please upgrade to a higher version.',
-            },
-            {
-                Version => '0.72.002',
-                Comment =>
-                    'This version is broken and not useable! Please upgrade to a higher version.',
-            },
-            {
-                Version => '0.72.003',
-                Comment =>
-                    'This version is broken and not useable! Please upgrade to a higher version.',
-            },
-        ],
-        InstTypes => {
-            aptget => 'libpdf-api2-perl',
-            ppm    => 'PDF-API2',
-            zypper => 'perl-PDF-API2',
-        },
-    },
     {
         Module    => 'Template',
         Required  => 1,
         Comment   => 'Template::Toolkit, the rendering engine of OTRS.',
         InstTypes => {
             aptget => 'libtemplate-perl',
-            ppm    => 'Template-Toolkit',
+            emerge => 'dev-perl/Template-Toolkit',
             zypper => 'perl-Template-Toolkit',
         },
     },
@@ -480,7 +396,7 @@ my @NeededModules = (
         Comment   => 'The fast data stash for Template::Toolkit.',
         InstTypes => {
             aptget => 'libtemplate-perl',
-            ppm    => 'Template-Toolkit',
+            emerge => 'dev-perl/Template-Toolkit',
             zypper => 'perl-Template-Toolkit',
         },
     },
@@ -490,7 +406,7 @@ my @NeededModules = (
         Comment   => 'Recommended for faster CSV handling.',
         InstTypes => {
             aptget => 'libtext-csv-xs-perl',
-            ppm    => 'Text-CSV_XS',
+            emerge => 'dev-perl/Text-CSV_XS',
             zypper => 'perl-Text-CSV_XS',
         },
     },
@@ -500,7 +416,7 @@ my @NeededModules = (
         Comment   => 'Required for high resolution timestamps.',
         InstTypes => {
             aptget => 'perl',
-            ppm    => 'Time-HiRes',
+            emerge => 'perl-core/Time-HiRes',
             zypper => 'perl-Time-HiRes',
         },
     },
@@ -510,13 +426,31 @@ my @NeededModules = (
         Required => 1,
         Comment  => 'Required for statistics.',
     },
+    {
+        Module    => 'XML::LibXML',
+        Required  => 0,
+        Comment   => 'Required for Generic Interface XSLT mapping module.',
+        InstTypes => {
+            aptget => 'libxml-libxml-perl',
+            zypper => 'perl-XML-LibXML',
+        },
+    },
+    {
+        Module    => 'XML::LibXSLT',
+        Required  => 0,
+        Comment   => 'Required for Generic Interface XSLT mapping module.',
+        InstTypes => {
+            aptget => 'libxml-libxslt-perl',
+            zypper => 'perl-XML-LibXSLT',
+        },
+    },
     {
         Module    => 'XML::Parser',
         Required  => 0,
         Comment   => 'Recommended for faster xml handling.',
         InstTypes => {
             aptget => 'libxml-parser-perl',
-            ppm    => 'XML-Parser',
+            emerge => 'dev-perl/XML-Parser',
             zypper => 'perl-XML-Parser',
         },
     },
@@ -526,36 +460,12 @@ my @NeededModules = (
         Comment   => 'Very important',
         InstTypes => {
             aptget => 'libyaml-libyaml-perl',
-            ppm    => 'YAML-XS',
+            emerge => 'dev-perl/YAML-LibYAML',
             zypper => 'perl-YAML-LibYAML',
         },
     },
 );
 
-# if we're on Windows we need some additional modules
-if ( $^O eq 'MSWin32' ) {
-
-    my @WindowsModules = (
-        {
-            Module    => 'Win32::Daemon',
-            Required  => 1,
-            Comment   => 'For running the OTRS Scheduler Service.',
-            InstTypes => {
-                ppm => 'Win32-Daemon',
-            },
-        },
-        {
-            Module    => 'Win32::Service',
-            Required  => 1,
-            Comment   => 'For running the OTRS Scheduler Service.',
-            InstTypes => {
-                ppm => 'Win32-Service',
-            },
-        },
-    );
-    push @NeededModules, @WindowsModules;
-}
-
 if ($PackageList) {
     my %PackageList = _PackageList( \@NeededModules );
 
@@ -603,12 +513,6 @@ else {
 sub _Check {
     my ( $Module, $Depends, $NoColors ) = @_;
 
-    # if we're on Windows we don't need to see Apache + mod_perl modules
-    if ( $^O eq 'MSWin32' ) {
-        return if $Module->{Module} =~ m{\A Apache }xms;
-        return if $Module->{Module} =~ m{\A ModPerl }xms;
-    }
-
     print "  " x ( $Depends + 1 );
     print "o $Module->{Module}";
     my $Length = 33 - ( length( $Module->{Module} ) + ( $Depends * 2 ) );
@@ -681,7 +585,6 @@ sub _Check {
             else {
                 print color('red') . 'FAILED!' . color('reset') . " $ErrorMessage\n";
             }
-            $ExitCode = 1;    # error
         }
         else {
             my $OutputVersion = $Version;
@@ -720,7 +623,6 @@ sub _Check {
         if ($Required) {
             $Required = 'required';
             $Color    = 'red';
-            $ExitCode = 1;            # error
         }
         else {
             $Required = 'optional';
@@ -755,10 +657,6 @@ sub _PackageList {
     # if we're on Windows we don't need to see Apache + mod_perl modules
     MODULE:
     for my $Module ( @{$PackageList} ) {
-        if ( $^O eq 'MSWin32' ) {
-            return if $Module->{Module} =~ m{\A Apache }xms;
-            return if $Module->{Module} =~ m{\A ModPerl }xms;
-        }
 
         my $Required = $Module->{Required};
         my $Version = Kernel::System::Environment->ModuleVersionGet( Module => $Module->{Module} );
@@ -871,14 +769,4 @@ sub _GetInstallCommand {
     );
 }
 
-sub _CheckActiveStatePerl {
-
-    # checks if active state perl on windows is activated
-    ## no critic
-    my $ActiveStatePerl = eval 'use Win32; return Win32::BuildNumber();';
-    ## use critic
-
-    return $ActiveStatePerl ? 1 : 0;
-}
-
-exit $ExitCode;
+exit 0;
